@@ -11,8 +11,6 @@ _url_list = ['http://almascience.org',
              'https://almascience.nrao.edu',
              'https://almascience.nao.ac.jp']
 
-_test_url_list = ['https://almascience-dev.nrao.edu']
-
 auth_urls = ['asa.alma.cl', 'rh-cas.alma.cl']
 
 
@@ -27,11 +25,6 @@ class Conf(_config.ConfigNamespace):
         _url_list,
         'The ALMA Archive mirror to use.')
 
-    test_archive_url = _config.ConfigItem(
-        _test_url_list,
-        'ALMA Archive Test Mirrors (temporary)'
-    )
-
     auth_url = _config.ConfigItem(
         auth_urls,
         'ALMA Central Authentication Service URLs'
@@ -44,9 +37,8 @@ class Conf(_config.ConfigNamespace):
 
 conf = Conf()
 
-from .core import Alma, AlmaClass
-from .utils import make_finder_chart
+from .core import Alma, AlmaClass, ALMA_BANDS
 
 __all__ = ['Alma', 'AlmaClass',
-           'Conf', 'conf',
+           'Conf', 'conf', 'ALMA_BANDS'
            ]
