@@ -7,19 +7,18 @@ CADC
 Module to query the Canadian Astronomy Data Centre (CADC).
 """
 
-import logging
+from astroquery import log
 import warnings
 import requests
 from numpy import ma
-from six.moves.urllib.parse import urlencode
-from six.moves.urllib_error import HTTPError
+from urllib.parse import urlencode
 
 from ..utils.class_or_instance import class_or_instance
 from ..utils import async_to_sync, commons
 from ..query import BaseQuery
 from bs4 import BeautifulSoup
 from astropy.utils.exceptions import AstropyDeprecationWarning
-from astroquery.utils.decorators import deprecated
+from astropy.utils.decorators import deprecated
 from astropy import units as u
 from . import conf
 
@@ -39,9 +38,7 @@ __all__ = ['Cadc', 'CadcClass']
 
 CADC_COOKIE_PREFIX = 'CADC_SSO'
 
-logger = logging.getLogger(__name__)
-
-# TODO figure out what do to if anything about them. Some might require
+# TODO figure out what to do if anything about them. Some might require
 # fixes on the CADC servers
 warnings.filterwarnings('ignore', module='astropy.io.votable')
 
@@ -193,7 +190,7 @@ class CadcClass(BaseQuery):
             try:
                 response.raise_for_status()
             except Exception as e:
-                logger.error('Logging error: {}'.format(e))
+                log.error('Logging error: {}'.format(e))
                 raise e
             # extract cookie
             cookie = '"{}"'.format(response.text)
@@ -209,7 +206,7 @@ class CadcClass(BaseQuery):
         """
         Logout. Anonymous access with all the subsequent use of the
         object. Note that the original session is not affected (in case
-        it was passed when the object was first intantiated)
+        it was passed when the object was first instantiated)
 
         Parameters
         ----------
@@ -356,9 +353,9 @@ class CadcClass(BaseQuery):
         for fn in filenames:
             try:
                 images.append(fn.get_fits())
-            except HTTPError as err:
+            except requests.exceptions.HTTPError as err:
                 # Catch HTTPError if user is unauthorized to access file
-                logger.debug(
+                log.debug(
                     "{} - Problem retrieving the file: {}".
                     format(str(err), str(err.url)))
                 pass
@@ -528,8 +525,10 @@ class CadcClass(BaseQuery):
                                urlencode({'ID': pid_sublist,
                                           'REQUEST': 'downloads-only'}, True)))
             for service_def in datalink:
-                if service_def.semantics == 'http://www.openadc.org/caom2#pkg':
-                    # pkg is an alternative for downloading multiple
+                if service_def.semantics in ['http://www.opencadc.org/caom2#pkg', '#package']:
+                    # TODO http://www.openadc.org/caom2#pkg has been replaced
+                    # by "package". Removed it after CADC rolls out the change
+                    # package is an alternative for downloading multiple
                     # data files in a tar file as an alternative to separate
                     # downloads. It doesn't make much sense in this case so
                     # filter it out.
@@ -585,7 +584,7 @@ class CadcClass(BaseQuery):
 
     def exec_sync(self, query, maxrec=None, uploads=None, output_file=None):
         """
-        Run a query and return the results or save them in a output_file
+        Run a query and return the results or save them in an output_file
 
         Parameters
         ----------
@@ -812,7 +811,7 @@ def get_access_url(service, capability=None):
                 response = requests.get(conf.CADC_REGISTRY_URL)
                 response.raise_for_status()
             except requests.exceptions.HTTPError as err:
-                logger.debug(
+                log.debug(
                     "ERROR getting the CADC registry: {}".format(str(err)))
                 raise err
             for line in response.text.splitlines():
@@ -836,7 +835,7 @@ def get_access_url(service, capability=None):
         response2 = requests.get(caps_url)
         response2.raise_for_status()
     except Exception as e:
-        logger.debug(
+        log.debug(
             "ERROR getting the service capabilities: {}".format(str(e)))
         raise e
 
@@ -851,7 +850,7 @@ def get_access_url(service, capability=None):
                     if not sm or sm.get("standardid", None) is None or\
                        sm['standardid'] == "ivo://ivoa.net/sso#cookie":
                         return i.accessurl.text
-    raise RuntimeError("ERROR - capabilitiy {} not found or not working with "
+    raise RuntimeError("ERROR - capability {} not found or not working with "
                        "anonymous or cookie access".format(capability))
 
 
