@@ -2,7 +2,8 @@
 
 # 1. standard library imports
 from io import BytesIO
-from urllib.parse import unquote
+import os
+from urllib.parse import unquote, urlparse
 import time
 from xml.etree import ElementTree
 from datetime import datetime, timezone
@@ -12,7 +13,7 @@ import astropy.units as u
 import astropy.coordinates as coord
 from astropy.table import Table
 from astropy.io.votable import parse
-from astropy import log
+from astroquery import log
 
 # 3. local imports - use relative imports
 # commonly required local imports shown below as example
@@ -101,18 +102,18 @@ class CasdaClass(BaseQuery):
 
         # Convert the coordinates to FK5
         coordinates = kwargs.get('coordinates')
-        c = commons.parse_coordinates(coordinates).transform_to(coord.FK5)
+        fk5_coords = commons.parse_coordinates(coordinates).transform_to(coord.FK5)
 
         if kwargs['radius'] is not None:
             radius = u.Quantity(kwargs['radius']).to(u.deg)
-            pos = 'CIRCLE {} {} {}'.format(c.ra.degree, c.dec.degree, radius.value)
+            pos = 'CIRCLE {} {} {}'.format(fk5_coords.ra.degree, fk5_coords.dec.degree, radius.value)
         elif kwargs['width'] is not None and kwargs['height'] is not None:
             width = u.Quantity(kwargs['width']).to(u.deg).value
             height = u.Quantity(kwargs['height']).to(u.deg).value
-            top = c.dec.degree - (height/2)
-            bottom = c.dec.degree + (height/2)
-            left = c.ra.degree - (width/2)
-            right = c.ra.degree + (width/2)
+            top = fk5_coords.dec.degree - (height/2)
+            bottom = fk5_coords.dec.degree + (height/2)
+            left = fk5_coords.ra.degree - (width/2)
+            right = fk5_coords.ra.degree + (width/2)
             pos = 'RANGE {} {} {} {}'.format(left, right, top, bottom)
         else:
             raise ValueError("Either 'radius' or both 'height' and 'width' must be supplied.")
@@ -184,13 +185,21 @@ class CasdaClass(BaseQuery):
 
         # Use datalink to get authenticated access for each file
         tokens = []
+        soda_url = None
         for row in table:
             access_url = row['access_url']
-            response = self._request('GET', access_url, auth=self._auth,
-                                     timeout=self.TIMEOUT, cache=False)
-            response.raise_for_status()
-            soda_url, id_token = self._parse_datalink_for_service_and_id(response, 'cutout_service')
-            tokens.append(id_token)
+            if access_url:
+                response = self._request('GET', access_url, auth=self._auth,
+                                        timeout=self.TIMEOUT, cache=False)
+                response.raise_for_status()
+                service_url, id_token = self._parse_datalink_for_service_and_id(response, 'async_service')
+                if id_token:
+                    tokens.append(id_token)
+                    soda_url = service_url
+
+        # Trap a request with no allowed data
+        if not soda_url:
+            raise ValueError('You do not have access to any of the requested data files.')
 
         # Create job to stage all files
         job_url = self._create_soda_job(tokens, soda_url=soda_url)
@@ -231,9 +240,15 @@ class CasdaClass(BaseQuery):
         # for each url in list, download file and checksum
         filenames = []
         for url in urls:
-            fn = self._request('GET', url, save=True, savedir=savedir, timeout=self.TIMEOUT, cache=False)
-            if fn:
-                filenames.append(fn)
+            parseResult = urlparse(url)
+            local_filename = unquote(os.path.basename(parseResult.path))
+            if os.name == 'nt':
+                # Windows doesn't allow special characters in filenames like
+                # ":" so replace them with an underscore
+                local_filename = local_filename.replace(':', '_')
+            local_filepath = os.path.join(savedir or self.cache_location or '.', local_filename)
+            self._download_file(url, local_filepath, timeout=self.TIMEOUT, cache=False)
+            filenames.append(local_filepath)
 
         return filenames
 
@@ -254,7 +269,7 @@ class CasdaClass(BaseQuery):
         """
         data = BytesIO(response.content)
 
-        votable = parse(data, pedantic=False)
+        votable = parse(data, verify='warn')
         results = next(resource for resource in votable.resources if
                        resource.type == "results")
         if results is None:
@@ -264,22 +279,22 @@ class CasdaClass(BaseQuery):
         authenticated_id_token = None
 
         # Find the authenticated id token for accessing the image cube
-        for x in results_array:
-            service_def = x['service_def']
+        for result in results_array:
+            service_def = result['service_def']
             if isinstance(service_def, bytes):
                 service_def = service_def.decode("utf8")
             if service_def == service_name:
-                authenticated_id_token = x['authenticated_id_token']
+                authenticated_id_token = result['authenticated_id_token']
                 if isinstance(service_def, bytes):
                     authenticated_id_token = authenticated_id_token.decode("utf8")
 
         # Find the async url
-        for x in votable.resources:
-            if x.type == "meta":
-                if x.ID == service_name:
-                    for p in x.params:
-                        if p.name == "accessURL":
-                            async_url = p.value
+        for resource in votable.resources:
+            if resource.type == "meta":
+                if resource.ID == service_name:
+                    for param in resource.params:
+                        if param.name == "accessURL":
+                            async_url = param.value
                             if isinstance(async_url, bytes):
                                 async_url = async_url.decode()
 
