@@ -18,12 +18,16 @@ class Conf(_config.ConfigNamespace):
     Configuration parameters for `astroquery.esa.hubble`.
     """
     DATA_ACTION = _config.ConfigItem("http://archives.esac.esa.int/"
-                                     "ehst-sl-server/servlet/data-action?",
+                                     "ehst-sl-server/servlet/data-action",
                                      "Main url for retriving hst files")
     METADATA_ACTION = _config.ConfigItem("http://archives.esac.esa.int/"
                                          "ehst-sl-server/servlet/"
-                                         "metadata-action?",
+                                         "metadata-action",
                                          "Main url for retriving hst metadata")
+    TARGET_ACTION = _config.ConfigItem("http://archives.esac.esa.int/"
+                                       "ehst-sl-server/servlet/"
+                                       "targetresolver-action",
+                                       "Main url for solving targets")
     TIMEOUT = 60
 
 
