@@ -1,5 +1,5 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import print_function
+
 
 # 1. standard library imports
 from numpy import nan
@@ -12,6 +12,7 @@ import warnings
 from astropy.table import Table, Column
 from astropy.io import ascii
 from astropy.time import Time
+from astropy.utils.exceptions import AstropyDeprecationWarning
 
 # 3. local imports - use relative imports
 # commonly required local imports shown below as example
@@ -29,59 +30,64 @@ __all__ = ['Horizons', 'HorizonsClass']
 class HorizonsClass(BaseQuery):
     """
     A class for querying the
-    `JPL Horizons <https://ssd.jpl.nasa.gov/horizons.cgi>`_ service.
+    `JPL Horizons <https://ssd.jpl.nasa.gov/horizons/>`_ service.
     """
 
     TIMEOUT = conf.timeout
 
     def __init__(self, id=None, location=None, epochs=None,
-                 id_type='smallbody'):
+                 id_type=None):
         """Instantiate JPL query.
 
         Parameters
         ----------
         id : str, required
-            Name, number, or designation of the object to be queried
+            Name, number, or designation of the object to be queried.
         location : str or dict, optional
-            Observer's location for ephemerides queries or center body
-            name for orbital element or vector queries. Uses the same
-            codes as JPL Horizons. If no location is provided, Earth's
-            center is used for ephemerides queries and the Sun's
-            center for elements and vectors queries. Arbitrary topocentic
-            coordinates for ephemerides queries can be provided in the
-            format of a dictionary. The
-            dictionary has to be of the form {``'lon'``: longitude in
-            deg (East positive, West negative), ``'lat'``: latitude in
-            deg (North positive, South negative), ``'elevation'``:
-            elevation in km above the reference ellipsoid, [``'body'``:
-            Horizons body ID of the central body; optional; if this value
-            is not provided it is assumed that this location is on Earth]}.
+            Observer's location for ephemerides queries or center body name for
+            orbital element or vector queries. Uses the same codes as JPL
+            Horizons. If no location is provided, Earth's center is used for
+            ephemerides queries and the Sun's center for elements and vectors
+            queries. Arbitrary topocentric coordinates for ephemerides queries
+            can be provided in the format of a dictionary. The dictionary has to
+            be of the form {``'lon'``: longitude in deg (East positive, West
+            negative), ``'lat'``: latitude in deg (North positive, South
+            negative), ``'elevation'``: elevation in km above the reference
+            ellipsoid, [``'body'``: Horizons body ID of the central body;
+            optional; if this value is not provided it is assumed that this
+            location is on Earth]}.
         epochs : scalar, list-like, or dictionary, optional
-            Either a list of epochs in JD or MJD format or a dictionary
-            defining a range of times and dates; the range dictionary has to
-            be of the form {``'start'``:'YYYY-MM-DD [HH:MM:SS]',
-            ``'stop'``:'YYYY-MM-DD [HH:MM:SS]', ``'step'``:'n[y|d|m|s]'}.
-            Epoch timescales depend on the type of query performed: UTC for
-            ephemerides queries, TDB for element queries, CT for vector queries.
-            If no epochs are provided, the current time is used.
+            Either a list of epochs in JD or MJD format or a dictionary defining
+            a range of times and dates; the range dictionary has to be of the
+            form {``'start'``: 'YYYY-MM-DD [HH:MM:SS]', ``'stop'``: 'YYYY-MM-DD
+            [HH:MM:SS]', ``'step'``: 'n[y|d|m|s]'}. Epoch timescales depend on
+            the type of query performed: UTC for ephemerides queries, TDB for
+            element and vector queries. If no epochs are provided, the current
+            time is used.
         id_type : str, optional
-            Identifier type, options:
-            ``'smallbody'``, ``'majorbody'`` (planets but also
-            anything that is not a small body), ``'designation'``,
-            ``'name'``, ``'asteroid_name'``, ``'comet_name'``,
-            ``'id'`` (Horizons id number), or ``'smallbody'`` (find the
-            closest match under any id_type), default: ``'smallbody'``
+            Controls Horizons's object selection for ``id``
+            [HORIZONSDOC_SELECTION]_ .  Options: ``'designation'`` (small body
+            designation), ``'name'`` (asteroid or comet name),
+            ``'asteroid_name'``, ``'comet_name'``, ``'smallbody'`` (asteroid
+            and comet search), or ``None`` (first search search planets,
+            natural satellites, spacecraft, and special cases, and if no
+            matches, then search small bodies).
+
+        References
+        ----------
+
+        .. [HORIZONSDOC_SELECTION] https://ssd.jpl.nasa.gov/horizons/manual.html#select (retrieved 2021 Sep 23).
 
 
         Examples
         --------
-            >>> from astroquery.jplhorizons import Horizons
-            >>> eros = Horizons(id='433', location='568',
-            ...              epochs={'start':'2017-01-01',
-            ...                      'stop':'2017-02-01',
-            ...                      'step':'1d'})
-            >>> print(eros)  # doctest: +SKIP
-            JPLHorizons instance "433"; location=568, epochs={'start': '2017-01-01', 'step': '1d', 'stop': '2017-02-01'}, id_type=smallbody
+        >>> from astroquery.jplhorizons import Horizons
+        >>> eros = Horizons(id='433', location='568',
+        ...              epochs={'start':'2017-01-01',
+        ...                      'stop':'2017-02-01',
+        ...                      'step':'1d'})
+        >>> print(eros)  # doctest: +SKIP
+        JPLHorizons instance "433"; location=568, epochs={'start': '2017-01-01', 'step': '1d', 'stop': '2017-02-01'}, id_type=None
         """
         super(HorizonsClass, self).__init__()
         self.id = id
@@ -103,9 +109,13 @@ class HorizonsClass(BaseQuery):
         self.epochs = epochs
 
         # check for id_type
-        if id_type not in ['smallbody', 'majorbody',
-                           'designation', 'name',
-                           'asteroid_name', 'comet_name', 'id']:
+        if id_type in ['majorbody', 'id']:
+            warnings.warn("``id_type``s 'majorbody' and 'id' are deprecated "
+                          "and replaced with ``None``, which has the same "
+                          "functionality.", AstropyDeprecationWarning)
+            id_type = None
+        if id_type not in [None, 'smallbody', 'designation', 'name',
+                           'asteroid_name', 'comet_name']:
             raise ValueError('id_type ({:s}) not allowed'.format(id_type))
         self.id_type = id_type
 
@@ -124,13 +134,13 @@ class HorizonsClass(BaseQuery):
 
         Examples
         --------
-            >>> from astroquery.jplhorizons import Horizons
-            >>> eros = Horizons(id='433', location='568',
-            ...                 epochs={'start':'2017-01-01',
-            ...                         'stop':'2017-02-01',
-            ...                         'step':'1d'})
-            >>> print(eros)  # doctest: +SKIP
-            JPLHorizons instance "433"; location=568, epochs={'start': '2017-01-01', 'step': '1d', 'stop': '2017-02-01'}, id_type=smallbody
+        >>> from astroquery.jplhorizons import Horizons
+        >>> eros = Horizons(id='433', location='568',
+        ...                 epochs={'start':'2017-01-01',
+        ...                         'stop':'2017-02-01',
+        ...                         'step':'1d'})
+        >>> print(eros)  # doctest: +SKIP
+        JPLHorizons instance "433"; location=568, epochs={'start': '2017-01-01', 'step': '1d', 'stop': '2017-02-01'}, id_type=None
         """
         return ('JPLHorizons instance \"{:s}\"; location={:s}, '
                 'epochs={:s}, id_type={:s}').format(
@@ -146,22 +156,22 @@ class HorizonsClass(BaseQuery):
                           rate_cutoff=None,
                           skip_daylight=False,
                           refraction=False,
-                          refsystem='J2000',
+                          refsystem='ICRF',
                           closest_apparition=False, no_fragments=False,
                           quantities=conf.eph_quantities,
                           get_query_payload=False,
                           get_raw_response=False, cache=True,
                           extra_precision=False):
         """
-        Query JPL Horizons for ephemerides. The ``location`` parameter
-        in ``HorizonsClass`` refers in this case to the location of
-        the observer.
+        Query JPL Horizons for ephemerides.
 
-        The following tables list the values queried, their
-        definitions, data types, units, and original Horizons
-        designations (where available). For more information on the
-        definitions of these quantities, please refer to the `Horizons
-        User Manual <https://ssd.jpl.nasa.gov/?horizons_doc>`_.
+        The ``location`` parameter in ``HorizonsClass`` refers in this case to
+        the location of the observer.
+
+        The following tables list the values queried, their definitions, data
+        types, units, and original Horizons designations (where available). For
+        more information on the definitions of these quantities, please refer to
+        the `Horizons User Manual <https://ssd.jpl.nasa.gov/?horizons_doc>`_.
 
 
 
@@ -417,40 +427,37 @@ class HorizonsClass(BaseQuery):
         max_hour_angle : float, optional
             Defines a maximum hour angle for the query, default: 0
         rate_cutoff : float, optional
-            Angular range rate upper limit cutoff in arcsec/h; default:
-            disabled
+            Angular range rate upper limit cutoff in arcsec/h; default: disabled
         skip_daylight : boolean, optional
             Crop daylight epochs in query, default: False
         refraction : boolean
-            If `True`, coordinates account for a standard atmosphere
-            refraction model; if `False`, coordinates do not account for
-            refraction (airless model); default: `False`
+            If ``True``, coordinates account for a standard atmosphere
+            refraction model; if ``False``, coordinates do not account for
+            refraction (airless model); default: ``False``
         refsystem : string
-            Coordinate reference system: ``'J2000'`` or ``'B1950'``;
-            default: ``'J2000'``
+            Coordinate reference system: ``'ICRF'`` or ``'B1950'``; default:
+            ``'ICRF'``
         closest_apparition : boolean, optional
-            Only applies to comets. This option will choose the
-            closest apparition available in time to the selected
-            epoch; default: False. Do not use this option for
-            non-cometary objects.
+            Only applies to comets. This option will choose the closest
+            apparition available in time to the selected epoch; default: False.
+            Do not use this option for non-cometary objects.
         no_fragments : boolean, optional
-            Only applies to comets. Reject all comet fragments from
-            selection; default: False. Do not use this option for
+            Only applies to comets. Reject all comet fragments from selection;
+            default: False. Do not use this option for
             non-cometary objects.
         quantities : integer or string, optional
             Single integer or comma-separated list in the form of a string
-            corresponding to all the
-            quantities to be queried from JPL Horizons using the coding
-            according to the `JPL Horizons User Manual Definition of
-            Observer Table Quantities
+            corresponding to all the quantities to be queried from JPL Horizons
+            using the coding according to the `JPL Horizons User Manual
+            Definition of Observer Table Quantities
             <https://ssd.jpl.nasa.gov/?horizons_doc#table_quantities>`_;
             default: all quantities
         get_query_payload : boolean, optional
-            When set to `True` the method returns the HTTP request
-            parameters as a dict, default: False
+            When set to `True` the method returns the HTTP request parameters as
+            a dict, default: False
         get_raw_response : boolean, optional
-            Return raw data as obtained by JPL Horizons without parsing the
-            data into a table, default: False
+            Return raw data as obtained by JPL Horizons without parsing the data
+            into a table, default: False
         extra_precision : boolean, optional
             Enables extra precision in RA and DEC values; default: False
 
@@ -463,32 +470,22 @@ class HorizonsClass(BaseQuery):
 
         Examples
         --------
-            >>> from astroquery.jplhorizons import Horizons
-            >>> obj = Horizons(id='Ceres', location='568',
-            ...             epochs={'start':'2010-01-01',
-            ...                     'stop':'2010-03-01',
-            ...                     'step':'10d'})
-            >>> eph = obj.ephemerides()  # doctest: +SKIP
-            >>> print(eph)  # doctest: +SKIP
-            targetname    datetime_str   datetime_jd ...   GlxLat  RA_3sigma
-            DEC_3sigma
-               ---            ---             d      ...    deg      arcsec
-            arcsec
-            ---------- ----------------- ----------- ... --------- ---------
-            ----------
-               1 Ceres 2010-Jan-01 00:00   2455197.5 ... 24.120057       0.0
-            0.0
-               1 Ceres 2010-Jan-11 00:00   2455207.5 ... 20.621496       0.0
-            0.0
-               1 Ceres 2010-Jan-21 00:00   2455217.5 ... 17.229529       0.0
-            0.0
-               1 Ceres 2010-Jan-31 00:00   2455227.5 ...  13.97264       0.0
-            0.0
-               1 Ceres 2010-Feb-10 00:00   2455237.5 ... 10.877201       0.0
-            0.0
-               1 Ceres 2010-Feb-20 00:00   2455247.5 ...  7.976737       0.0
-            0.0
-
+        >>> from astroquery.jplhorizons import Horizons
+        >>> obj = Horizons(id='Ceres', location='568',
+        ...             epochs={'start':'2010-01-01',
+        ...                     'stop':'2010-03-01',
+        ...                     'step':'10d'})
+        >>> eph = obj.ephemerides()  # doctest: +SKIP
+        >>> print(eph)  # doctest: +SKIP
+            targetname       datetime_str   datetime_jd ...  PABLon  PABLat
+               ---               ---             d      ...   deg     deg
+        ----------------- ----------------- ----------- ... -------- ------
+        1 Ceres (A801 AA) 2010-Jan-01 00:00   2455197.5 ... 238.2494 4.5532
+        1 Ceres (A801 AA) 2010-Jan-11 00:00   2455207.5 ... 241.3339 4.2832
+        1 Ceres (A801 AA) 2010-Jan-21 00:00   2455217.5 ... 244.3394 4.0089
+        1 Ceres (A801 AA) 2010-Jan-31 00:00   2455227.5 ... 247.2518 3.7289
+        1 Ceres (A801 AA) 2010-Feb-10 00:00   2455237.5 ... 250.0576 3.4415
+        1 Ceres (A801 AA) 2010-Feb-20 00:00   2455247.5 ... 252.7383 3.1451
         """
 
         URL = conf.horizons_server
@@ -522,8 +519,8 @@ class HorizonsClass(BaseQuery):
                 commandline += ' NOFRAG;'
 
         request_payload = OrderedDict([
-            ('batch', 1),
-            ('TABLE_TYPE', 'OBSERVER'),
+            ('format', 'text'),
+            ('EPHEM_TYPE', 'OBSERVER'),
             ('QUANTITIES', "'"+str(quantities)+"'"),
             ('COMMAND', '"' + commandline + '"'),
             ('SOLAR_ELONG', ('"' + str(solar_elongation[0]) + "," +
@@ -534,7 +531,7 @@ class HorizonsClass(BaseQuery):
             ('ANG_FORMAT', ('DEG')),
             ('APPARENT', ({False: 'AIRLESS',
                            True: 'REFRACTED'}[refraction])),
-            ('REF_SYSTEM', (refsystem)),
+            ('REF_SYSTEM', refsystem),
             ('EXTRA_PREC', {True: 'YES', False: 'NO'}[extra_precision])])
 
         if isinstance(self.location, dict):
@@ -609,21 +606,21 @@ class HorizonsClass(BaseQuery):
         return response
 
     def elements_async(self, get_query_payload=False,
-                       refsystem='J2000',
+                       refsystem='ICRF',
                        refplane='ecliptic',
                        tp_type='absolute',
                        closest_apparition=False, no_fragments=False,
                        get_raw_response=False, cache=True):
         """
-        Query JPL Horizons for osculating orbital elements. The ``location``
-        parameter in ``HorizonsClass`` refers in this case to the  center
-        body relative to which the elements are provided.
+        Query JPL Horizons for osculating orbital elements.
 
-        The following table lists the values queried, their
-        definitions, data types, units, and original Horizons
-        designations (where available). For more information on the
-        definitions of these quantities, please refer to the `Horizons
-        User Manual <https://ssd.jpl.nasa.gov/?horizons_doc>`_.
+        The ``location`` parameter in ``HorizonsClass`` refers in this case to
+        the center body relative to which the elements are provided.
+
+        The following table lists the values queried, their definitions, data
+        types, units, and original Horizons designations (where available). For
+        more information on the definitions of these quantities, please refer to
+        the `Horizons User Manual <https://ssd.jpl.nasa.gov/?horizons_doc>`_.
 
         +------------------+-----------------------------------------------+
         | Column Name      | Definition                                    |
@@ -677,32 +674,29 @@ class HorizonsClass(BaseQuery):
         Parameters
         ----------
         refsystem : string
-            Element reference system for geometric and astrometric
-            quantities: ``'J2000'`` or ``'B1950'``; default: ``'J2000'``
+            Element reference system for geometric and astrometric quantities:
+            ``'ICRF'`` or ``'B1950'``; default: ``'ICRF'``
         refplane : string
-            Reference plane for all output quantities: ``'ecliptic'``
-            (ecliptic and mean equinox of reference epoch), ``'earth'``
-            (Earth mean equator and equinox of reference epoch), or
-            ``'body'`` (body mean equator and node of date); default:
-            ``'ecliptic'``
+            Reference plane for all output quantities: ``'ecliptic'`` (ecliptic
+            and mean equinox of reference epoch), ``'earth'`` (Earth mean
+            equator and equinox of reference epoch), or ``'body'`` (body mean
+            equator and node of date); default: ``'ecliptic'``
         tp_type : string
             Representation for time-of-perihelion passage: ``'absolute'`` or
             ``'relative'`` (to epoch); default: ``'absolute'``
         closest_apparition : boolean, optional
-            Only applies to comets. This option will choose the
-            closest apparition available in time to the selected
-            epoch; default: False. Do not use this option for
-            non-cometary objects.
+            Only applies to comets. This option will choose the closest
+            apparition available in time to the selected epoch; default: False.
+            Do not use this option for non-cometary objects.
         no_fragments : boolean, optional
-            Only applies to comets. Reject all comet fragments from
-            selection; default: False. Do not use this option for
-            non-cometary objects.
+            Only applies to comets. Reject all comet fragments from selection;
+            default: False. Do not use this option for non-cometary objects.
         get_query_payload : boolean, optional
-            When set to ``True`` the method returns the HTTP request
-            parameters as a dict, default: False
+            When set to ``True`` the method returns the HTTP request parameters
+            as a dict, default: False
         get_raw_response: boolean, optional
-            Return raw data as obtained by JPL Horizons without parsing the
-            data into a table, default: False
+            Return raw data as obtained by JPL Horizons without parsing the data
+            into a table, default: False
 
 
         Returns
@@ -760,8 +754,8 @@ class HorizonsClass(BaseQuery):
 
         # configure request_payload for ephemerides query
         request_payload = OrderedDict([
-            ('batch', 1),
-            ('TABLE_TYPE', 'ELEMENTS'),
+            ('format', 'text'),
+            ('EPHEM_TYPE', 'ELEMENTS'),
             ('MAKE_EPHEM', 'YES'),
             ('OUT_UNITS', 'AU-D'),
             ('COMMAND', '"' + commandline + '"'),
@@ -825,15 +819,15 @@ class HorizonsClass(BaseQuery):
                       refplane='ecliptic', aberrations='geometric',
                       delta_T=False,):
         """
-        Query JPL Horizons for state vectors. The ``location``
-        parameter in ``HorizonsClass`` refers in this case to the center
-        body relative to which the vectors are provided.
+        Query JPL Horizons for state vectors.
 
-        The following table lists the values queried, their
-        definitions, data types, units, and original Horizons
-        designations (where available). For more information on the
-        definitions of these quantities, please refer to the `Horizons
-        User Manual <https://ssd.jpl.nasa.gov/?horizons_doc>`_.
+        The ``location`` parameter in ``HorizonsClass`` refers in this case to
+        the center body relative to which the vectors are provided.
+
+        The following table lists the values queried, their definitions, data
+        types, units, and original Horizons designations (where available). For
+        more information on the definitions of these quantities, please refer to
+        the `Horizons User Manual <https://ssd.jpl.nasa.gov/?horizons_doc>`_.
 
         +------------------+-----------------------------------------------+
         | Column Name      | Definition                                    |
@@ -891,26 +885,26 @@ class HorizonsClass(BaseQuery):
         Parameters
         ----------
         closest_apparition : boolean, optional
-            Only applies to comets. This option will choose the
-            closest apparition available in time to the selected
-            epoch; default: False. Do not use this option for
-            non-cometary objects.
+            Only applies to comets. This option will choose the closest
+            apparition available in time to the selected epoch; default: False.
+            Do not use this option for non-cometary objects.
         no_fragments : boolean, optional
-            Only applies to comets. Reject all comet fragments from
-            selection; default: False. Do not use this option for
-            non-cometary objects.
+            Only applies to comets. Reject all comet fragments from selection;
+            default: False. Do not use this option for non-cometary objects.
         get_query_payload : boolean, optional
-            When set to `True` the method returns the HTTP request
-            parameters as a dict, default: False
+            When set to `True` the method returns the HTTP request parameters as
+            a dict, default: False
         get_raw_response: boolean, optional
-            Return raw data as obtained by JPL Horizons without parsing the
-            data into a table, default: False
+            Return raw data as obtained by JPL Horizons without parsing the data
+            into a table, default: False
         refplane : string
-            Reference plane for all output quantities: ``'ecliptic'``
-            (ecliptic and mean equinox of reference epoch), ``'earth'``
-            (Earth mean equator and equinox of reference epoch), or
-            ``'body'`` (body mean equator and node of date); default:
-            ``'ecliptic'``
+            Reference plane for all output quantities: ``'ecliptic'`` (ecliptic
+            and mean equinox of reference epoch), ``'earth'`` (Earth mean
+            equator and equinox of reference epoch), or ``'body'`` (body mean
+            equator and node of date); default: ``'ecliptic'``.
+
+            See :ref:`Horizons Reference Frames <jpl-horizons-reference-frames>`
+            in the astroquery documentation for details.
         aberrations : string, optional
             Aberrations to be accounted for: [``'geometric'``,
             ``'astrometric'``, ``'apparent'``]. Default: ``'geometric'``
@@ -991,19 +985,22 @@ class HorizonsClass(BaseQuery):
 
         # configure request_payload for ephemerides query
         request_payload = OrderedDict([
-            ('batch', 1),
-            ('TABLE_TYPE', 'VECTORS'),
+            ('format', 'text'),
+            ('EPHEM_TYPE', 'VECTORS'),
             ('OUT_UNITS', 'AU-D'),
             ('COMMAND', '"' + commandline + '"'),
             ('CENTER', ("'" + str(self.location) + "'")),
             ('CSV_FORMAT', ('"YES"')),
-            ('REF_PLANE', {'ecliptic': 'ECLIPTIC', 'earth': 'FRAME',
+            ('REF_PLANE', {'ecliptic': 'ECLIPTIC',
+                           'earth': 'FRAME',
+                           'frame': 'FRAME',
                            'body': "'BODY EQUATOR'"}[refplane]),
-            ('REF_SYSTEM', 'J2000'),
+            ('REF_SYSTEM', 'ICRF'),
             ('TP_TYPE', 'ABSOLUTE'),
-            ('LABELS', 'YES'),
-            ('VECT_CORR', {'geometric': '"NONE"', 'astrometric': '"LT"',
-                           'apparent': '"LT+S"'}[aberrations]),
+            ('VEC_LABELS', 'YES'),
+            ('VEC_CORR', {'geometric': '"NONE"',
+                          'astrometric': '"LT"',
+                          'apparent': '"LT+S"'}[aberrations]),
             ('VEC_DELTA_T', {True: 'YES', False: 'NO'}[delta_T]),
             ('OBJ_DATA', 'YES')]
         )
@@ -1290,11 +1287,20 @@ class HorizonsClass(BaseQuery):
         data : `astropy.Table`
 
         """
+        self.last_response = response
         if self.query_type not in ['ephemerides', 'elements', 'vectors']:
             return None
         else:
-            data = self._parse_horizons(response.text)
-
+            try:
+                data = self._parse_horizons(response.text)
+            except Exception as ex:
+                try:
+                    self._last_query.remove_cache_file(self.cache_location)
+                except OSError:
+                    # this is allowed: if `cache` was set to False, this
+                    # won't be needed
+                    pass
+                raise
         return data
 
 
