@@ -30,15 +30,18 @@ class Conf(_config.ConfigNamespace):
 
 conf = Conf()
 
-from .cutouts import TesscutClass, Tesscut
+from .cutouts import TesscutClass, Tesscut, ZcutClass, Zcut
 from .observations import Observations, ObservationsClass, MastClass, Mast
 from .collections import Catalogs, CatalogsClass
+from .missions import MastMissions, MastMissionsClass
 from .core import MastQueryWithLogin
 from . import utils
 
 __all__ = ['Observations', 'ObservationsClass',
            'Catalogs', 'CatalogsClass',
+           'MastMissions', 'MastMissionsClass',
            'Mast', 'MastClass',
            'Tesscut', 'TesscutClass',
+           'Zcut', 'ZcutClass',
            'Conf', 'conf', 'utils',
            ]
