@@ -6,7 +6,6 @@ MAST Observations
 This module contains various methods for querying MAST observations.
 """
 
-
 import warnings
 import json
 import time
@@ -21,13 +20,12 @@ import astropy.units as u
 import astropy.coordinates as coord
 
 from astropy.table import Table, Row, vstack, MaskedColumn
-from astropy.logger import log
+from astroquery import log
 
 from astropy.utils import deprecated
 from astropy.utils.console import ProgressBarOrSpinner
-from astropy.utils.exceptions import AstropyDeprecationWarning
 
-from six.moves.urllib.parse import quote as urlencode
+from urllib.parse import quote as urlencode
 
 from ..query import QueryWithLogin
 from ..utils import commons, async_to_sync
@@ -39,7 +37,6 @@ from ..exceptions import (TimeoutError, InvalidQueryError, RemoteServiceError,
 from . import conf, utils
 from .core import MastQueryWithLogin
 
-
 __all__ = ['Observations', 'ObservationsClass',
            'MastClass', 'Mast']
 
@@ -52,7 +49,14 @@ class ObservationsClass(MastQueryWithLogin):
     Class for querying MAST observational data.
     """
 
-    def _parse_result(self, responses, verbose=False):  # Used by the async_to_sync decorator functionality
+    # Calling static class variables
+    _caom_all = 'Mast.Caom.All'
+    _caom_cone = 'Mast.Caom.Cone'
+    _caom_filtered_position = 'Mast.Caom.Filtered.Position'
+    _caom_filtered = 'Mast.Caom.Filtered'
+    _caom_products = 'Mast.Caom.Products'
+
+    def _parse_result(self, responses, *, verbose=False):  # Used by the async_to_sync decorator functionality
         """
         Parse the results of a list of `~requests.Response` objects and returns an `~astropy.table.Table` of results.
 
@@ -77,13 +81,13 @@ class ObservationsClass(MastQueryWithLogin):
         Lists data missions archived by MAST and avaiable through `astroquery.mast`.
 
         Returns
-        --------
+        -------
         response : list
             List of available missions.
         """
 
         # getting all the histogram information
-        service = "Mast.Caom.All"
+        service = self._caom_all
         params = {}
         response = self._portal_api_connection.service_request_async(service, params, format='extjs')
         json_response = response[0].json()
@@ -107,15 +111,15 @@ class ObservationsClass(MastQueryWithLogin):
             The query to get metadata for. Options are observations, and products.
 
         Returns
-        --------
+        -------
         response : `~astropy.table.Table`
             The metadata table.
         """
 
         if query_type.lower() == "observations":
-            colconf_name = "Mast.Caom.Cone"
+            colconf_name = self._caom_cone
         elif query_type.lower() == "products":
-            colconf_name = "Mast.Caom.Products"
+            colconf_name = self._caom_products
         else:
             raise InvalidQueryError("Unknown query type.")
 
@@ -151,38 +155,16 @@ class ObservationsClass(MastQueryWithLogin):
         objectname = criteria.pop('objectname', None)
         radius = criteria.pop('radius', 0.2*u.deg)
 
-        # Dealing with observation type (science vs calibration)
-        if ('obstype' in criteria) and ('intentType' in criteria):
-            warn_string = ("Cannot specify both obstype and intentType, "
-                           "obstype is the deprecated version of intentType and will be ignored.")
-            warnings.warn(warn_string, InputWarning)
-            criteria.pop('obstype', None)
-
-        # Temporarily issuing warning about change in behavior
-        # continuing old behavior
-        # grabbing the observation type (science vs calibration)
-        obstype = criteria.pop('obstype', None)
-        if obstype:
-            warn_string = ("Criteria obstype argument disappeared in May 2019. "
-                          "Criteria 'obstype' is now 'intentType', options are 'science' or 'calibration', "
-                          "if intentType is not supplied all observations (science and calibration) are returned.")
-            warnings.warn(warn_string, AstropyDeprecationWarning)
-
-            if obstype == "science":
-                criteria["intentType"] = "science"
-            elif obstype == "cal":
-                criteria["intentType"] = "calibration"
-
         # Build the mashup filter object and store it in the correct service_name entry
         if coordinates or objectname:
-            mashup_filters = self._portal_api_connection.build_filter_set("Mast.Caom.Cone",
-                                                                           "Mast.Caom.Filtered.Position",
-                                                                           **criteria)
+            mashup_filters = self._portal_api_connection.build_filter_set(self._caom_cone,
+                                                            self._caom_filtered_position,
+                                                            **criteria)
             coordinates = utils.parse_input_location(coordinates, objectname)
         else:
-            mashup_filters = self._portal_api_connection.build_filter_set("Mast.Caom.Cone",
-                                                                           "Mast.Caom.Filtered",
-                                                                           **criteria)
+            mashup_filters = self._portal_api_connection.build_filter_set(self._caom_cone,
+                                                            self._caom_filtered,
+                                                            **criteria)
 
         # handle position info (if any)
         position = None
@@ -191,13 +173,13 @@ class ObservationsClass(MastQueryWithLogin):
             # if radius is just a number we assume degrees
             radius = coord.Angle(radius, u.deg)
 
-            # build the coordinates string needed by Mast.Caom.Filtered.Position
+            # build the coordinates string needed by ObservationsClass._caom_filtered_position
             position = ', '.join([str(x) for x in (coordinates.ra.deg, coordinates.dec.deg, radius.deg)])
 
         return position, mashup_filters
 
     @class_or_instance
-    def query_region_async(self, coordinates, radius=0.2*u.deg, pagesize=None, page=None):
+    def query_region_async(self, coordinates, *, radius=0.2*u.deg, pagesize=None, page=None):
         """
         Given a sky position and radius, returns a list of MAST observations.
         See column documentation `here <https://mast.stsci.edu/api/v0/_c_a_o_mfields.html>`__.
@@ -232,15 +214,15 @@ class ObservationsClass(MastQueryWithLogin):
         # if radius is just a number we assume degrees
         radius = coord.Angle(radius, u.deg)
 
-        service = 'Mast.Caom.Cone'
+        service = self._caom_cone
         params = {'ra': coordinates.ra.deg,
                   'dec': coordinates.dec.deg,
                   'radius': radius.deg}
 
-        return self._portal_api_connection.service_request_async(service, params, pagesize, page)
+        return self._portal_api_connection.service_request_async(service, params, pagesize=pagesize, page=page)
 
     @class_or_instance
-    def query_object_async(self, objectname, radius=0.2*u.deg, pagesize=None, page=None):
+    def query_object_async(self, objectname, *, radius=0.2*u.deg, pagesize=None, page=None):
         """
         Given an object name, returns a list of MAST observations.
         See column documentation `here <https://mast.stsci.edu/api/v0/_c_a_o_mfields.html>`__.
@@ -270,10 +252,10 @@ class ObservationsClass(MastQueryWithLogin):
 
         coordinates = utils.resolve_object(objectname)
 
-        return self.query_region_async(coordinates, radius, pagesize, page)
+        return self.query_region_async(coordinates, radius=radius, pagesize=pagesize, page=page)
 
     @class_or_instance
-    def query_criteria_async(self, pagesize=None, page=None, **criteria):
+    def query_criteria_async(self, *, pagesize=None, page=None, **criteria):
         """
         Given an set of criteria, returns a list of MAST observations.
         Valid criteria are returned by ``get_metadata("observations")``
@@ -309,18 +291,18 @@ class ObservationsClass(MastQueryWithLogin):
             raise InvalidQueryError("At least one non-positional criterion must be supplied.")
 
         if position:
-            service = "Mast.Caom.Filtered.Position"
+            service = self._caom_filtered_position
             params = {"columns": "*",
                       "filters": mashup_filters,
                       "position": position}
         else:
-            service = "Mast.Caom.Filtered"
+            service = self._caom_filtered
             params = {"columns": "*",
                       "filters": mashup_filters}
 
         return self._portal_api_connection.service_request_async(service, params)
 
-    def query_region_count(self, coordinates, radius=0.2*u.deg, pagesize=None, page=None):
+    def query_region_count(self, coordinates, *, radius=0.2*u.deg, pagesize=None, page=None):
         """
         Given a sky position and radius, returns the number of MAST observations in that region.
 
@@ -345,7 +327,7 @@ class ObservationsClass(MastQueryWithLogin):
         response : int
         """
 
-        # build the coordinates string needed by Mast.Caom.Filtered.Position
+        # build the coordinates string needed by ObservationsClass._caom_filtered_position
         coordinates = commons.parse_coordinates(coordinates)
 
         # if radius is just a number we assume degrees
@@ -354,14 +336,14 @@ class ObservationsClass(MastQueryWithLogin):
         # turn coordinates into the format
         position = ', '.join([str(x) for x in (coordinates.ra.deg, coordinates.dec.deg, radius.deg)])
 
-        service = "Mast.Caom.Filtered.Position"
+        service = self._caom_filtered_position
         params = {"columns": "COUNT_BIG(*)",
                   "filters": [],
                   "position": position}
 
         return int(self._portal_api_connection.service_request(service, params, pagesize, page)[0][0])
 
-    def query_object_count(self, objectname, radius=0.2*u.deg, pagesize=None, page=None):
+    def query_object_count(self, objectname, *, radius=0.2*u.deg, pagesize=None, page=None):
         """
         Given an object name, returns the number of MAST observations.
 
@@ -387,9 +369,9 @@ class ObservationsClass(MastQueryWithLogin):
 
         coordinates = utils.resolve_object(objectname)
 
-        return self.query_region_count(coordinates, radius, pagesize, page)
+        return self.query_region_count(coordinates, radius=radius, pagesize=pagesize, page=page)
 
-    def query_criteria_count(self, pagesize=None, page=None, **criteria):
+    def query_criteria_count(self, *, pagesize=None, page=None, **criteria):
         """
         Given an set of filters, returns the number of MAST observations meeting those criteria.
 
@@ -422,12 +404,12 @@ class ObservationsClass(MastQueryWithLogin):
 
         # send query
         if position:
-            service = "Mast.Caom.Filtered.Position"
+            service = self._caom_filtered_position
             params = {"columns": "COUNT_BIG(*)",
                       "filters": mashup_filters,
                       "position": position}
         else:
-            service = "Mast.Caom.Filtered"
+            service = self._caom_filtered
             params = {"columns": "COUNT_BIG(*)",
                       "filters": mashup_filters}
 
@@ -452,19 +434,23 @@ class ObservationsClass(MastQueryWithLogin):
         """
 
         # getting the obsid list
-        if type(observations) == Row:
+        if isinstance(observations, Row):
             observations = observations["obsid"]
         if np.isscalar(observations):
-            observations = [observations]
-        if type(observations) == Table:
+            observations = np.array([observations])
+        if isinstance(observations, Table):
             observations = observations['obsid']
 
-        service = 'Mast.Caom.Products'
+        observations = observations[observations != ""]
+        if len(observations) == 0:
+            raise InvalidQueryError("Observation list is empty, no associated products.")
+
+        service = self._caom_products
         params = {'obsid': ','.join(observations)}
 
         return self._portal_api_connection.service_request_async(service, params)
 
-    def filter_products(self, products, mrp_only=False, extension=None, **filters):
+    def filter_products(self, products, *, mrp_only=False, extension=None, **filters):
         """
         Takes an `~astropy.table.Table` of MAST observation data products and filters it based on given filters.
 
@@ -496,7 +482,7 @@ class ObservationsClass(MastQueryWithLogin):
             filter_mask &= (products['productGroupDescription'] == "Minimum Recommended Products")
 
         if extension:
-            if type(extension) == str:
+            if isinstance(extension, str):
                 extension = [extension]
 
             mask = np.full(len(products), False, dtype=bool)
@@ -508,7 +494,7 @@ class ObservationsClass(MastQueryWithLogin):
         # Applying the rest of the filters
         for colname, vals in filters.items():
 
-            if type(vals) == str:
+            if isinstance(vals, str):
                 vals = [vals]
 
             mask = np.full(len(products), False, dtype=bool)
@@ -519,7 +505,84 @@ class ObservationsClass(MastQueryWithLogin):
 
         return products[np.where(filter_mask)]
 
-    def _download_files(self, products, base_dir, cache=True, cloud_only=False,):
+    def download_file(self, uri, *, local_path=None, base_url=None, cache=True, cloud_only=False):
+        """
+        Downloads a single file based on the data URI
+
+        Parameters
+        ----------
+        uri : str
+            The product dataURI, e.g. mast:JWST/product/jw00736-o039_t001_miri_ch1-long_x1d.fits
+        local_path : str
+            Directory in which the files will be downloaded.  Defaults to current working directory.
+        base_url: str
+            A base url to use when downloading.  Default is the MAST Portal API
+        cache : bool
+            Default is True. If file is found on disk it will not be downloaded again.
+        cloud_only : bool, optional
+            Default False. If set to True and cloud data access is enabled (see `enable_cloud_dataset`)
+            files that are not found in the cloud will be skipped rather than downloaded from MAST
+            as is the default behavior. If cloud access is not enables this argument as no affect.
+
+        Returns
+        -------
+        status: str
+            download status message.  Either COMPLETE, SKIPPED, or ERROR.
+        msg : str
+            An error status message, if any.
+        url : str
+            The full url download path
+        """
+
+        # create the full data URL
+        base_url = base_url if base_url else self._portal_api_connection.MAST_DOWNLOAD_URL
+        data_url = base_url + "?uri=" + uri
+
+        # create a local file path if none is input.  Use current directory as default.
+        if not local_path:
+            filename = os.path.basename(uri)
+            local_path = os.path.join(os.path.abspath('.'), filename)
+
+        # recreate the data_product key for cloud connection check
+        data_product = {'dataURI': uri}
+
+        status = "COMPLETE"
+        msg = None
+        url = None
+
+        try:
+            if self._cloud_connection is not None and self._cloud_connection.is_supported(data_product):
+                try:
+                    self._cloud_connection.download_file(data_product, local_path, cache)
+                except Exception as ex:
+                    log.exception("Error pulling from S3 bucket: {}".format(ex))
+                    if cloud_only:
+                        log.warn("Skipping file...")
+                        local_path = ""
+                        status = "SKIPPED"
+                    else:
+                        log.warn("Falling back to mast download...")
+                        self._download_file(data_url, local_path,
+                                            cache=cache, head_safe=True, continuation=False)
+            else:
+                self._download_file(data_url, local_path,
+                                    cache=cache, head_safe=True, continuation=False)
+
+            # check if file exists also this is where would perform md5,
+            # and also check the filesize if the database reliably reported file sizes
+            if (not os.path.isfile(local_path)) and (status != "SKIPPED"):
+                status = "ERROR"
+                msg = "File was not downloaded"
+                url = data_url
+
+        except HTTPError as err:
+            status = "ERROR"
+            msg = "HTTPError: {0}".format(err)
+            url = data_url
+
+        return status, msg, url
+
+    def _download_files(self, products, base_dir, *, cache=True, cloud_only=False,):
         """
         Takes an `~astropy.table.Table` of data products and downloads them into the directory given by base_dir.
 
@@ -544,47 +607,15 @@ class ObservationsClass(MastQueryWithLogin):
         manifest_array = []
         for data_product in products:
 
+            # create the local file download path
             local_path = os.path.join(base_dir, data_product['obs_collection'], data_product['obs_id'])
-            data_url = self._portal_api_connection.MAST_DOWNLOAD_URL + "?uri=" + data_product["dataURI"]
-
             if not os.path.exists(local_path):
                 os.makedirs(local_path)
+            local_path = os.path.join(local_path, os.path.basename(data_product['productFilename']))
 
-            local_path = os.path.join(local_path, data_product['productFilename'])
-
-            status = "COMPLETE"
-            msg = None
-            url = None
-
-            try:
-                if self._cloud_connection is not None and self._cloud_connection.is_supported(data_product):
-                    try:
-                        self._cloud_connection.download_file(data_product, local_path, cache)
-                    except Exception as ex:
-                        log.exception("Error pulling from S3 bucket: {}".format(ex))
-                        if cloud_only:
-                            log.warn("Skipping file...")
-                            local_path = ""
-                            status = "SKIPPED"
-                        else:
-                            log.warn("Falling back to mast download...")
-                            self._download_file(data_url, local_path,
-                                                cache=cache, head_safe=True, continuation=False)
-                else:
-                    self._download_file(data_url, local_path,
-                                        cache=cache, head_safe=True, continuation=False)
-
-                # check if file exists also this is where would perform md5,
-                # and also check the filesize if the database reliably reported file sizes
-                if (not os.path.isfile(local_path)) and (status != "SKIPPED"):
-                    status = "ERROR"
-                    msg = "File was not downloaded"
-                    url = data_url
-
-            except HTTPError as err:
-                status = "ERROR"
-                msg = "HTTPError: {0}".format(err)
-                url = data_url
+            # download the files
+            status, msg, url = self.download_file(data_product["dataURI"], local_path=local_path,
+                                                  cache=cache, cloud_only=cloud_only)
 
             manifest_array.append([local_path, status, msg, url])
 
@@ -627,7 +658,7 @@ class ObservationsClass(MastQueryWithLogin):
                           'Message': [msg]})
         return manifest
 
-    def download_products(self, products, download_dir=None,
+    def download_products(self, products, *, download_dir=None,
                           cache=True, curl_flag=False, mrp_only=False, cloud_only=False, **filters):
         """
         Download data products.
@@ -665,12 +696,15 @@ class ObservationsClass(MastQueryWithLogin):
         response : `~astropy.table.Table`
             The manifest of files downloaded, or status of files on disk if curl option chosen.
         """
+        # If the products list is a row we need to cast it as a table
+        if isinstance(products, Row):
+            products = Table(products, masked=True)
 
         # If the products list is not already a table of products we need to
         # get the products and filter them appropriately
-        if type(products) != Table:
+        if not isinstance(products, Table):
 
-            if type(products) == str:
+            if isinstance(products, str):
                 products = [products]
 
             # collect list of products
@@ -681,7 +715,7 @@ class ObservationsClass(MastQueryWithLogin):
             products = vstack(product_lists)
 
         # apply filters
-        products = self.filter_products(products, mrp_only, **filters)
+        products = self.filter_products(products, mrp_only=mrp_only, **filters)
 
         if not len(products):
             warnings.warn("No products to download.", NoResultsWarning)
@@ -692,19 +726,19 @@ class ObservationsClass(MastQueryWithLogin):
             download_dir = '.'
 
         if curl_flag:  # don't want to download the files now, just the curl script
-            manifest = self._download_curl_script(products, download_dir)
+            manifest = self._download_curl_script(products,
+                                                  download_dir)
 
         else:
             base_dir = download_dir.rstrip('/') + "/mastDownload"
-            manifest = self._download_files(products, base_dir, cache, cloud_only)
+            manifest = self._download_files(products,
+                                            base_dir=base_dir,
+                                            cache=cache,
+                                            cloud_only=cloud_only)
 
         return manifest
 
-    @deprecated(since="v0.3.9", alternative="get_cloud_uris")
-    def get_hst_s3_uris(self, data_products, include_bucket=True, full_url=False):
-        return self.get_cloud_uris(data_products, include_bucket, full_url)
-
-    def get_cloud_uris(self, data_products, include_bucket=True, full_url=False):
+    def get_cloud_uris(self, data_products, *, include_bucket=True, full_url=False):
         """
         Takes an `~astropy.table.Table` of data products and returns the associated cloud data uris.
 
@@ -728,15 +762,12 @@ class ObservationsClass(MastQueryWithLogin):
         """
 
         if self._cloud_connection is None:
-            raise AttributeError("Must enable s3 dataset before attempting to query the s3 information")
+            raise RemoteServiceError('Please enable anonymous cloud access by calling `enable_cloud_dataset` method. '
+                                     'See MAST Labs documentation for an example: https://mast-labs.stsci.io/#example-data-access-with-astroquery-observations')
 
         return self._cloud_connection.get_cloud_uri_list(data_products, include_bucket, full_url)
 
-    @deprecated(since="v0.3.9", alternative="get_cloud_uri")
-    def get_hst_s3_uri(self, data_product, include_bucket=True, full_url=False):
-        return self.get_cloud_uri(data_product, include_bucket, full_url)
-
-    def get_cloud_uri(self, data_product, include_bucket=True, full_url=False):
+    def get_cloud_uri(self, data_product, *, include_bucket=True, full_url=False):
         """
         For a given data product, returns the associated cloud URI.
         If the product is from a mission that does not support cloud access an
@@ -763,8 +794,10 @@ class ObservationsClass(MastQueryWithLogin):
         """
 
         if self._cloud_connection is None:
-            raise AttributeError("Must enable s3 dataset before attempting to query the s3 information")
+            raise RemoteServiceError('Please enable anonymous cloud access by calling `enable_cloud_dataset` method. '
+                                     'See MAST Labs documentation for an example: https://mast-labs.stsci.io/#example-data-access-with-astroquery-observations')
 
+        # Query for product URIs
         return self._cloud_connection.get_cloud_uri(data_product, include_bucket, full_url)
 
 
@@ -777,7 +810,7 @@ class MastClass(MastQueryWithLogin):
     more flexible but less user friendly than `ObservationsClass`.
     """
 
-    def _parse_result(self, responses, verbose=False):  # Used by the async_to_sync decorator functionality
+    def _parse_result(self, responses, *, verbose=False):  # Used by the async_to_sync decorator functionality
         """
         Parse the results of a list of `~requests.Response` objects and returns an `~astropy.table.Table` of results.
 
@@ -798,7 +831,7 @@ class MastClass(MastQueryWithLogin):
         return self._portal_api_connection._parse_result(responses, verbose)
 
     @class_or_instance
-    def service_request_async(self, service, params, pagesize=None, page=None, **kwargs):
+    def service_request_async(self, service, params, *, pagesize=None, page=None, **kwargs):
         """
         Given a Mashup service and parameters, builds and excecutes a Mashup query.
         See documentation `here <https://mast.stsci.edu/api/v0/class_mashup_1_1_mashup_request.html>`__
