@@ -11,7 +11,11 @@ from astropy.time import Time
 from astropy.table import Table, QTable, Column
 import astropy.units as u
 from astropy.coordinates import EarthLocation, Angle, SkyCoord
-from astropy._erfa.core import ErfaWarning
+try:
+    from astropy.utils.exceptions import ErfaWarning
+except ImportError:
+    # DEPRECATED: remove eventually, but needed in July 2020
+    from astropy._erfa.core import ErfaWarning
 
 from ..query import BaseQuery
 from . import conf
@@ -1123,7 +1127,7 @@ class MPCClass(BaseQuery):
             tab = ascii.read(text_table, format='fixed_width_no_header',
                              names=names, col_starts=col_starts,
                              col_ends=col_ends, data_start=data_start,
-                             fill_values=(('N/A', np.nan),))
+                             fill_values=(('N/A', np.nan),), fast_reader=False)
 
             for col, unit in zip(names, units):
                 tab[col].unit = unit
@@ -1204,7 +1208,8 @@ class MPCClass(BaseQuery):
                                   col_starts=(0, 5, 12, 13, 14, 15,
                                               32, 44, 65, 70, 77),
                                   col_ends=(4, 11, 12, 13, 14, 31,
-                                            43, 55, 69, 70, 79))
+                                            43, 55, 69, 70, 79),
+                                  fast_reader=False)
 
                 # convert asteroid designations
                 # old designation style, e.g.: 1989AB
@@ -1248,7 +1253,8 @@ class MPCClass(BaseQuery):
                                   col_starts=(0, 4, 5, 13, 14, 15,
                                               32, 44, 65, 70, 77),
                                   col_ends=(3, 4, 12, 13, 14, 31,
-                                            43, 55, 69, 70, 79))
+                                            43, 55, 69, 70, 79),
+                                  fast_reader=False)
 
                 # convert comet designations
                 ident = data['desig'][0]
