@@ -1,18 +1,17 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import print_function
+
 
 import numpy as np
 
-from astropy.tests.helper import remote_data
 from astropy.table import Table
 import astropy.units as u
-from six import PY2
+
 import pytest
 
 from ... import nist
 
 
-@remote_data
+@pytest.mark.remote_data
 class TestNist:
 
     def test_query_async(self):
@@ -27,7 +26,6 @@ class TestNist:
         # (regression test for 1355)
         assert np.all(result['TP'] == 'T8637')
 
-    @pytest.mark.skipif('PY2')
     def test_unescape_html(self):
         response = nist.core.Nist.query_async(4333 * u.AA, 4334 * u.AA, "V I")
         assert '&dagger;' in response.text
