@@ -4,16 +4,17 @@ from __future__ import (absolute_import, division, print_function,
 import abc
 import inspect
 import pickle
+import copy
 import getpass
 import hashlib
 import keyring
 import io
 import os
 import requests
+import textwrap
 
-import six
 from astropy.config import paths
-from astropy.logger import log
+from astroquery import log
 import astropy.units as u
 from astropy.utils.console import ProgressBarOrSpinner
 import astropy.utils.data
@@ -26,6 +27,10 @@ __all__ = ['BaseQuery', 'QueryWithLogin']
 
 def to_cache(response, cache_file):
     log.debug("Caching data to {0}".format(cache_file))
+    response = copy.deepcopy(response)
+    if hasattr(response, 'request'):
+        for key in tuple(response.request.hooks.keys()):
+            del response.request.hooks[key]
     with open(cache_file, "wb") as f:
         pickle.dump(response, f)
 
@@ -34,7 +39,7 @@ def _replace_none_iterable(iterable):
     return tuple('' if i is None else i for i in iterable)
 
 
-class AstroQuery(object):
+class AstroQuery:
 
     def __init__(self, method, url,
                  params=None, data=None, headers=None,
@@ -90,7 +95,7 @@ class AstroQuery(object):
                                                  key=_replace_none_iterable)),)
                 elif k is None:
                     request_key += (None,)
-                elif isinstance(k, six.string_types):
+                elif isinstance(k, str):
                     request_key += (k,)
                 else:
                     raise TypeError("{0} must be a dict, tuple, str, or "
@@ -115,6 +120,19 @@ class AstroQuery(object):
             log.debug("Retrieving data from {0}".format(request_file))
         return response
 
+    def remove_cache_file(self, cache_location):
+        """
+        Remove the cache file - may be needed if a query fails during parsing
+        (successful request, but failed return)
+        """
+        request_file = self.request_file(cache_location)
+
+        if os.path.exists(request_file):
+            os.remove(request_file)
+        else:
+            raise OSError(f"Tried to remove cache file {request_file} but "
+                          "it does not exist")
+
 
 class LoginABCMeta(abc.ABCMeta):
     """
@@ -137,22 +155,21 @@ class LoginABCMeta(abc.ABCMeta):
                 bases[0].login(*args, **kwargs)
 
             login.__doc__ = attrs['_login'].__doc__
-            if not six.PY2:
-                login.__signature__ = inspect.signature(attrs['_login'])
+            login.__signature__ = inspect.signature(attrs['_login'])
             setattr(newcls, login.__name__, login)
 
         return newcls
 
 
-@six.add_metaclass(LoginABCMeta)
-class BaseQuery(object):
+class BaseQuery(metaclass=LoginABCMeta):
     """
     This is the base class for all the query classes in astroquery. It
     is implemented as an abstract class and must not be directly instantiated.
     """
 
     def __init__(self):
-        S = self._session = requests.session()
+        S = self._session = requests.Session()
+        self._session.hooks['response'].append(self._response_hook)
         S.headers['User-Agent'] = (
             'astroquery/{vers} {olduseragent}'
             .format(vers=version.version,
@@ -161,20 +178,53 @@ class BaseQuery(object):
         self.cache_location = os.path.join(
             paths.get_cache_dir(), 'astroquery',
             self.__class__.__name__.split("Class")[0])
-        if not os.path.exists(self.cache_location):
-            os.makedirs(self.cache_location)
+        os.makedirs(self.cache_location, exist_ok=True)
         self._cache_active = True
 
     def __call__(self, *args, **kwargs):
         """ init a fresh copy of self """
         return self.__class__(*args, **kwargs)
 
+    def _response_hook(self, response, *args, **kwargs):
+        loglevel = log.getEffectiveLevel()
+
+        if loglevel >= 10:
+            # Log request at DEBUG severity
+            request_hdrs = '\n'.join(f'{k}: {v}' for k, v in response.request.headers.items())
+            request_log = textwrap.indent(
+                f"-----------------------------------------\n"
+                f"{response.request.method} {response.request.url}\n"
+                f"{request_hdrs}\n"
+                f"\n"
+                f"{response.request.body}\n"
+                f"-----------------------------------------", '\t')
+            log.debug(f"HTTP request\n{request_log}")
+        if loglevel >= 5:
+            # Log response at super-DEBUG severity
+            response_hdrs = '\n'.join(f'{k}: {v}' for k, v in response.headers.items())
+            if kwargs.get('stream'):
+                response_log = textwrap.indent(
+                    f"-----------------------------------------\n"
+                    f"{response.status_code} {response.reason} {response.url}\n"
+                    f"{response_hdrs}\n"
+                    "Streaming Data\n"
+                    f"-----------------------------------------", '\t')
+            else:
+                response_log = textwrap.indent(
+                    f"-----------------------------------------\n"
+                    f"{response.status_code} {response.reason} {response.url}\n"
+                    f"{response_hdrs}\n"
+                    f"\n"
+                    f"{response.text}\n"
+                    f"-----------------------------------------", '\t')
+            log.log(5, f"HTTP response\n{response_log}")
+
     def _request(self, method, url,
                  params=None, data=None, headers=None,
                  files=None, save=False, savedir='', timeout=None, cache=True,
                  stream=False, auth=None, continuation=True, verify=True,
                  allow_redirects=True,
-                 json=None):
+                 json=None, return_response_on_save=False):
         """
         A generic HTTP request method, similar to `requests.Session.request`
         but with added caching-related tools
@@ -213,6 +263,9 @@ class BaseQuery(object):
             parameter will try to continue the download where it left off.
             See `_download_file`.
         stream : bool
+        return_response_on_save : bool
+            If ``save``, also return the server response. The default is to only
+            return the local file path.
 
         Returns
         -------
@@ -220,7 +273,11 @@ class BaseQuery(object):
             The response from the server if ``save`` is False
         local_filepath : list
             a list of strings containing the downloaded local paths if ``save``
-            is True
+            is True and ``return_response_on_save`` is False.
+        (local_filepath, response) : tuple(list, `requests.Response`)
+            a tuple containing a list of strings containing the downloaded local paths,
+            and the server response object, if ``save`` is True and ``return_response_on_save``
+            is True.
         """
         req_kwargs = dict(
             params=params,
@@ -238,11 +295,14 @@ class BaseQuery(object):
                 local_filename = local_filename.replace(':', '_')
             local_filepath = os.path.join(savedir or self.cache_location or '.', local_filename)
 
-            self._download_file(url, local_filepath, cache=cache,
-                                continuation=continuation, method=method,
-                                allow_redirects=allow_redirects,
-                                auth=auth, **req_kwargs)
-            return local_filepath
+            response = self._download_file(url, local_filepath, cache=cache,
+                                           continuation=continuation, method=method,
+                                           allow_redirects=allow_redirects,
+                                           auth=auth, **req_kwargs)
+            if return_response_on_save:
+                return local_filepath, response
+            else:
+                return local_filepath
         else:
             query = AstroQuery(method, url, **req_kwargs)
             if ((self.cache_location is None) or (not self._cache_active) or (not cache)):
@@ -333,16 +393,14 @@ class BaseQuery(object):
                                                  timeout=timeout, stream=True,
                                                  auth=auth, **kwargs)
                 response.raise_for_status()
+                del self._session.headers['Range']
 
         elif cache and os.path.exists(local_filepath):
             if length is not None:
                 statinfo = os.stat(local_filepath)
                 if statinfo.st_size != length:
-                    log.warning("Found cached file {0} with size {1} that is "
-                                "different from expected size {2}"
-                                .format(local_filepath,
-                                        statinfo.st_size,
-                                        length))
+                    log.warning(f"Found cached file {local_filepath} with size {statinfo.st_size} "
+                                f"that is different from expected size {length}")
                     open_mode = 'wb'
                 else:
                     log.info("Found cached file {0} with expected size {1}."
@@ -363,6 +421,9 @@ class BaseQuery(object):
 
         blocksize = astropy.utils.data.conf.download_block_size
 
+        log.debug(f"Downloading URL {url} to {local_filepath} with size {length} "
+                  f"by blocks of {blocksize}")
+
         bytes_read = 0
 
         # Only show progress bar if logging level is INFO or lower.
@@ -371,20 +432,16 @@ class BaseQuery(object):
         else:
             progress_stream = io.StringIO()
 
-        with ProgressBarOrSpinner(
-                length, ('Downloading URL {0} to {1} ...'
-                         .format(url, local_filepath)),
-                file=progress_stream) as pb:
+        with ProgressBarOrSpinner(length, f'Downloading URL {url} to {local_filepath} ...',
+                                  file=progress_stream) as pb:
             with open(local_filepath, open_mode) as f:
                 for block in response.iter_content(blocksize):
                     f.write(block)
-                    bytes_read += blocksize
+                    bytes_read += len(block)
                     if length is not None:
-                        pb.update(bytes_read if bytes_read <= length else
-                                  length)
+                        pb.update(bytes_read if bytes_read <= length else length)
                     else:
                         pb.update(bytes_read)
-
         response.close()
         return response
 
