@@ -3,21 +3,32 @@ import numpy as np
 from numpy.testing import assert_allclose
 import pytest
 
-from astropy import coordinates
+from astropy.coordinates import SkyCoord
 from astropy.table import Table
 
-from six.moves.urllib_error import URLError
+from urllib.error import URLError
 
 from ... import sdss
 from ...exceptions import TimeoutError
 
+# DR11 is a quasi-internal data release that does not have SkyServer support.
+dr_list = (8, 9, 10, 12, 13, 14, 15, 16, 17)
+
 
 @pytest.mark.remote_data
 class TestSDSSRemote:
     # Test Case: A Seyfert 1 galaxy
-    coords = coordinates.SkyCoord('0h8m05.63s +14d50m23.3s')
+    coords = SkyCoord('0h8m05.63s +14d50m23.3s')
     mintimeout = 1e-2
 
+    @pytest.fixture()
+    def large_results(self):
+        # Large list of objects for regression tests
+        query = "select top 1000 z, ra, dec, bestObjID from specObj where class = 'galaxy' and programname = 'eboss'"
+        results = sdss.SDSS.query_sql(query)
+        coords_large = SkyCoord(ra=results['ra'], dec=results['dec'], unit='deg')
+        return coords_large
+
     def test_images_timeout(self):
         """
         This test *must* be run before `test_sdss_image` because that query
@@ -34,10 +45,19 @@ class TestSDSSRemote:
                          "error with 'No route to host'.  We don't know a "
                          "workaround for this yet.")
 
-    def test_sdss_spectrum(self):
-        xid = sdss.SDSS.query_region(self.coords, spectro=True)
+    @pytest.mark.parametrize("dr", dr_list)
+    def test_sdss_spectrum(self, dr):
+        xid = sdss.SDSS.query_region(self.coords, spectro=True, data_release=dr)
         assert isinstance(xid, Table)
-        sp = sdss.SDSS.get_spectra(matches=xid)
+        sp = sdss.SDSS.get_spectra(matches=xid, data_release=dr)
+
+    def test_sdss_spectrum_plate_mjd_fiber(self):
+        """These plates are only available in recent data releases.
+        """
+        sp = sdss.SDSS.get_spectra(plate=9403, mjd=58018, fiberID=485,
+                                   data_release=16)
+        sp = sdss.SDSS.get_spectra(plate=10909, mjd=58280, fiberID=485,
+                                   data_release=16)
 
     def test_sdss_spectrum_mjd(self):
         sp = sdss.SDSS.get_spectra(plate=2345, fiberID=572)
@@ -75,25 +95,22 @@ class TestSDSSRemote:
 
     def test_sdss_specobj(self):
         colnames = ['ra', 'dec', 'objid', 'run', 'rerun', 'camcol', 'field',
-                    'z', 'plate', 'mjd', 'fiberID', 'specobjid', 'run2d',
-                    'instrument']
+                    'z', 'plate', 'mjd', 'fiberID', 'specobjid', 'run2d']
         dtypes = [float, float, np.int64, int, int, int, int, float, int, int,
-                  int, np.int64, int, bytes]
+                  int, np.int64, int]
         data = [
             [46.8390680395307, 5.16972676625711, 1237670015125750016, 5714,
              301, 2, 185, -0.0006390358, 2340, 53733, 291, 2634685834112034816,
-             26, 'SDSS'],
+             26],
             [46.8705377929765, 5.42458826592292, 1237670015662621224, 5714,
-             301, 3, 185, 0, 2340, 53733, 3, 2634606669274834944, 26, 'SDSS'],
+             301, 3, 185, 0, 2340, 53733, 3, 2634606669274834944, 26],
             [46.8899751105478, 5.09432755808192, 1237670015125815346, 5714,
              301, 2, 186, -4.898809E-05, 2340, 53733, 287, 2634684734600407040,
-             26, 'SDSS'],
+             26],
             [46.8954031261838, 5.9739184644185, 1237670016199491831, 5714,
-             301, 4, 185, 0, 2340, 53733, 329, 2634696279472498688, 26,
-             'SDSS'],
+             301, 4, 185, 0, 2340, 53733, 329, 2634696279472498688, 26],
             [46.9155836662379, 5.50671723824944, 1237670015662686398, 5714,
-             301, 3, 186, 0, 2340, 53733, 420, 2634721293362030592, 26,
-             'SDSS']]
+             301, 3, 186, 0, 2340, 53733, 420, 2634721293362030592, 26]]
         table = Table(data=[x for x in zip(*data)],
                       names=colnames, dtype=dtypes)
         xid = sdss.SDSS.query_specobj(plate=2340)
@@ -148,20 +165,41 @@ class TestSDSSRemote:
 
     def test_query_non_default_field(self):
         # A regression test for #469
-        query1 = sdss.SDSS.query_region(self.coords, fields=['r'])
+        query1 = sdss.SDSS.query_region(self.coords, fields=['r', 'psfMag_r'])
 
         query2 = sdss.SDSS.query_region(self.coords, fields=['ra', 'dec', 'r'])
         assert isinstance(query1, Table)
         assert isinstance(query2, Table)
 
-        assert query1.colnames == ['r']
+        assert query1.colnames == ['r', 'psfMag_r']
         assert query2.colnames == ['ra', 'dec', 'r']
 
-    def test_query_crossid(self):
-        query1 = sdss.SDSS.query_crossid(self.coords)
+    @pytest.mark.parametrize("dr", dr_list)
+    def test_query_crossid(self, dr):
+        query1 = sdss.SDSS.query_crossid(self.coords, data_release=dr)
         query2 = sdss.SDSS.query_crossid([self.coords, self.coords])
         assert isinstance(query1, Table)
         assert query1['objID'][0] == 1237652943176138868
 
         assert isinstance(query2, Table)
         assert query2['objID'][0] == query1['objID'][0] == query2['objID'][1]
+
+    @pytest.mark.parametrize("dr", dr_list)
+    def test_spectro_query_crossid(self, dr):
+        query1 = sdss.SDSS.query_crossid(self.coords,
+                                         specobj_fields=['specObjID', 'z'],
+                                         data_release=dr, cache=False)
+        query2 = sdss.SDSS.query_crossid([self.coords, self.coords],
+                                         specobj_fields=['specObjID', 'z'],
+                                         data_release=dr, cache=False)
+        assert isinstance(query1, Table)
+        assert query1['specObjID'][0] == 845594848269461504
+
+        assert isinstance(query2, Table)
+        assert query2['specObjID'][0] == query2['specObjID'][1] == query1['specObjID'][0]
+
+    def test_large_crossid(self, large_results):
+        # Regression test for #589
+
+        results = sdss.SDSS.query_crossid(large_results)
+        assert len(results) == 894
