@@ -2,15 +2,15 @@
 import os
 import re
 
-import six
 import pytest
 import astropy.units as u
 from astropy.table import Table
 import numpy as np
 
 from ... import simbad
-from ...utils.testing_tools import MockResponse
+from astroquery.utils.mocks import MockResponse
 from ...utils import commons
+from ...query import AstroQuery
 from ...exceptions import TableParseError
 from .test_simbad_remote import multicoords
 
@@ -38,7 +38,7 @@ DATA_FILES = {
 class MockResponseSimbad(MockResponse):
     query_regex = re.compile(r'query\s+([a-z]+)\s+')
 
-    def __init__(self, script, cache=True, **kwargs):
+    def __init__(self, script, cache=False, **kwargs):
         # preserve, e.g., headers
         super(MockResponseSimbad, self).__init__(**kwargs)
         self.content = self.get_content(script)
@@ -58,18 +58,17 @@ def data_path(filename):
 
 @pytest.fixture
 def patch_post(request):
-    try:
-        mp = request.getfixturevalue("monkeypatch")
-    except AttributeError:  # pytest < 3
-        mp = request.getfuncargvalue("monkeypatch")
+    mp = request.getfixturevalue("monkeypatch")
+
     mp.setattr(simbad.SimbadClass, '_request', post_mockreturn)
+
     return mp
 
 
 def post_mockreturn(self, method, url, data, timeout, **kwargs):
     response = MockResponseSimbad(data['script'], **kwargs)
 
-    class last_query(object):
+    class last_query:
         pass
 
     self._last_query = last_query()
@@ -113,26 +112,29 @@ def test_get_frame_coordinates(coordinates, expected_frame):
     actual_frame = simbad.core._get_frame_coords(coordinates)[2]
     assert actual_frame == expected_frame
     if actual_frame == 'GAL':
-        l, b = simbad.core._get_frame_coords(coordinates)[:2]
-        np.testing.assert_almost_equal(float(l) % 360, -67.02084 % 360)
-        np.testing.assert_almost_equal(float(b), -29.75447)
+        l_gal, b_gal = simbad.core._get_frame_coords(coordinates)[:2]
+        np.testing.assert_almost_equal(float(l_gal) % 360, -67.02084 % 360)
+        np.testing.assert_almost_equal(float(b_gal), -29.75447)
 
 
 def test_parse_result():
-    result1 = simbad.core.Simbad._parse_result(
+    sb = simbad.core.Simbad()
+    # need _last_query to be defined
+    sb._last_query = AstroQuery('GET', 'http://dummy')
+    result1 = sb._parse_result(
         MockResponseSimbad('query id '), simbad.core.SimbadVOTableResult)
     assert isinstance(result1, Table)
     with pytest.raises(TableParseError) as ex:
-        simbad.core.Simbad._parse_result(MockResponseSimbad('query error '),
-                                         simbad.core.SimbadVOTableResult)
+        sb._parse_result(MockResponseSimbad('query error '),
+                simbad.core.SimbadVOTableResult)
     assert str(ex.value) == ('Failed to parse SIMBAD result! The raw response '
                              'can be found in self.last_response, and the '
                              'error in self.last_table_parse_error. '
                              'The attempted parsed result is in '
                              'self.last_parsed_result.\n Exception: 7:115: '
                              'no element found')
-    assert isinstance(simbad.Simbad.last_response.text, six.string_types)
-    assert isinstance(simbad.Simbad.last_response.content, six.binary_type)
+    assert isinstance(sb.last_response.text, str)
+    assert isinstance(sb.last_response.content, bytes)
 
 
 votable_fields = ",".join(simbad.core.Simbad.get_votable_fields())
