@@ -7,10 +7,9 @@ ftp://ftp.cv.nrao.edu/NRAO-staff/bkent/slap/idl/
 :author: Adam Ginsburg <adam.g.ginsburg@gmail.com>
 """
 import warnings
-import sys
 from astropy.io import ascii
 from astropy import units as u
-from astropy import log
+from astroquery import log
 from ..query import BaseQuery
 from ..utils import async_to_sync, prepend_docstr_nosections
 from . import conf
@@ -22,10 +21,6 @@ __all__ = ['Splatalogue', 'SplatalogueClass']
 # example query of SPLATALOGUE directly:
 # https://www.cv.nrao.edu/php/splat/c.php?sid%5B%5D=64&sid%5B%5D=108&calcIn=&data_version=v3.0&from=&to=&frequency_units=MHz&energy_range_from=&energy_range_to=&lill=on&tran=&submit=Search&no_atmospheric=no_atmospheric&no_potential=no_potential&no_probable=no_probable&include_only_nrao=include_only_nrao&displayLovas=displayLovas&displaySLAIM=displaySLAIM&displayJPL=displayJPL&displayCDMS=displayCDMS&displayToyaMA=displayToyaMA&displayOSU=displayOSU&displayRecomb=displayRecomb&displayLisa=displayLisa&displayRFI=displayRFI&ls1=ls1&ls5=ls5&el1=el1
 
-if sys.version_info.major == 2:
-    # can't do unicode doctests in py2
-    __doctest_skip__ = ['SplatalogueClass.get_species_ids']
-
 
 @async_to_sync
 class SplatalogueClass(BaseQuery):
@@ -81,7 +76,7 @@ class SplatalogueClass(BaseQuery):
         """
         self.data.update(self._parse_kwargs(**kwargs))
 
-    def get_species_ids(self, restr=None, reflags=0):
+    def get_species_ids(self, restr=None, reflags=0, recache=False):
         """
         Get a dictionary of "species" IDs, where species refers to the molecule
         name, mass, and chemical composition.
@@ -93,6 +88,8 @@ class SplatalogueClass(BaseQuery):
             species whose names match
         reflags : int
             Flags to pass to `re`.
+        recache : bool
+            Flag whether to refresh the local cache of species IDs
 
         Examples
         --------
@@ -137,7 +134,7 @@ class SplatalogueClass(BaseQuery):
         # loading can be an expensive operation and should not change at
         # runtime: do it lazily
         if not hasattr(self, '_species_ids'):
-            self._species_ids = load_species_table.species_lookuptable()
+            self._species_ids = load_species_table.species_lookuptable(recache=recache)
 
         if restr is not None:
             return self._species_ids.find(restr, reflags)
