@@ -7,7 +7,7 @@ import requests
 from astropy import units as u
 
 from ... import splatalogue
-from ...utils.testing_tools import MockResponse
+from astroquery.utils.mocks import MockResponse
 
 SPLAT_DATA = 'CO_colons.csv'
 
@@ -19,10 +19,8 @@ def data_path(filename):
 
 @pytest.fixture
 def patch_post(request):
-    try:
-        mp = request.getfixturevalue("monkeypatch")
-    except AttributeError:  # pytest < 3
-        mp = request.getfuncargvalue("monkeypatch")
+    mp = request.getfixturevalue("monkeypatch")
+
     mp.setattr(requests.Session, 'request', post_mockreturn)
     return mp
 
@@ -61,12 +59,6 @@ def test_load_species_table():
     assert len(CO) == 4
 
 
-# regression test: ConfigItems were in wrong order at one point
-def test_url():
-    assert 'https://' in splatalogue.core.Splatalogue.QUERY_URL
-    assert 'cv.nrao.edu' in splatalogue.core.Splatalogue.QUERY_URL
-
-
 # regression test: get_query_payload should work (#308)
 def test_get_payload():
     q = splatalogue.core.Splatalogue.query_lines_async(1 * u.GHz, 10 * u.GHz,
