@@ -8,15 +8,15 @@ import warnings
 import os
 import shutil
 import socket
+from io import BytesIO, StringIO
+from urllib.error import URLError
 
 import requests
 
-from six.moves.urllib_error import URLError
-import six
 import astropy.units as u
 from astropy import coordinates as coord
 from collections import OrderedDict
-from astropy.utils import minversion
+from astropy.utils import deprecated, minversion
 import astropy.utils.data as aud
 from astropy.io import fits, votable
 
@@ -51,11 +51,16 @@ __all__ = ['send_request',
            'TableList',
            'suppress_vo_warnings',
            'validate_email',
-           'ASTROPY_LT_4_1']
+           'ASTROPY_LT_4_1',
+           'ASTROPY_LT_4_3',
+           'ASTROPY_LT_5_0']
 
 ASTROPY_LT_4_1 = not minversion('astropy', '4.1')
+ASTROPY_LT_4_3 = not minversion('astropy', '4.3')
+ASTROPY_LT_5_0 = not minversion('astropy', '5.0')
 
 
+@deprecated('0.4.4', alternative='astroquery.query.BaseQuery._request')
 def send_request(url, data, timeout, request_type='POST', headers={},
                  **kwargs):
     """
@@ -126,11 +131,11 @@ def radius_to_unit(radius, unit='degree'):
     """
     rad = coord.Angle(radius)
 
-    if isinstance(unit, six.string_types):
+    if isinstance(unit, str):
         if hasattr(rad, unit):
             return getattr(rad, unit)
-        elif hasattr(rad, unit + 's'):
-            return getattr(rad, unit + 's')
+        elif hasattr(rad, f"{unit}s"):
+            return getattr(rad, f"{unit}s")
 
     return rad.to(unit).value
 
@@ -157,7 +162,7 @@ def parse_coordinates(coordinates):
     astropy.units.UnitsError
     TypeError
     """
-    if isinstance(coordinates, six.string_types):
+    if isinstance(coordinates, str):
         try:
             c = ICRSCoordGenerator(coordinates)
             warnings.warn("Coordinate string is being interpreted as an "
@@ -169,7 +174,8 @@ def parse_coordinates(coordinates):
                           "appropriate astropy.coordinates object.", InputWarning)
             raise u.UnitsError
         except ValueError as err:
-            if isinstance(err.args[1], u.UnitsError):
+            if ((ASTROPY_LT_5_0 and isinstance(err.args[1], u.UnitsError)) or
+                (not ASTROPY_LT_5_0 and isinstance(err.__context__, u.UnitsError))):
                 try:
                     c = ICRSCoordGenerator(coordinates, unit='deg')
                     warnings.warn("Coordinate string is being interpreted as an "
@@ -345,7 +351,7 @@ def validate_email(email):
         return bool(re.compile(r'^\S+@\S+\.\S+$').match(email))
 
 
-class FileContainer(object):
+class FileContainer:
     """
     A File Object container, meant to offer lazy access to downloaded FITS
     files.
@@ -389,22 +395,10 @@ class FileContainer(object):
             If the system is unable to create a hardlink, the file will be
             copied to the target location.
         """
-        from warnings import warn
-
         self.get_fits()
+        target_key = str(self._target)
 
-        try:
-            dldir, urlmapfn = aud._get_download_cache_locs()
-        except (IOError, OSError) as e:
-            msg = 'Remote data cache could not be accessed due to '
-            estr = '' if len(e.args) < 1 else (': ' + str(e))
-            warn(aud.CacheMissingWarning(msg + e.__class__.__name__ + estr))
-
-        with _open_shelve(urlmapfn, True) as url2hash:
-            if str(self._target) in url2hash:
-                target = url2hash[str(self._target)]
-            else:
-                raise IOError("Cached file not found / does not exist.")
+        target = aud.download_file(target_key, cache=True, sources=[])
 
         if link_cache == 'hard':
             try:
@@ -442,18 +436,16 @@ class FileContainer(object):
         Return the file as an io.StringIO object
         """
         s = self.get_string()
-        # TODO: replace with six.BytesIO
         try:
-            return six.BytesIO(s)
+            return BytesIO(s)
         except TypeError:
-            return six.StringIO(s)
+            return StringIO(s)
 
     def __repr__(self):
         if hasattr(self, '_fits'):
-            return "Downloaded FITS file: " + self._fits.__repr__()
+            return f"Downloaded FITS file: {self._fits!r}"
         else:
-            return ("Downloaded object from URL {} with ID {}"
-                    .format(self._target, id(self._readable_object)))
+            return f"Downloaded object from URL {self._target} with ID {id(self._readable_object)}"
 
 
 def get_readable_fileobj(*args, **kwargs):
@@ -468,24 +460,5 @@ def parse_votable(content):
     """
     Parse a votable in string format
     """
-    tables = votable.parse(six.BytesIO(content), pedantic=False)
+    tables = votable.parse(BytesIO(content), verify='warn')
     return tables
-
-
-def _open_shelve(shelffn, withclosing=False):
-    """
-    Opens a shelf file.  If ``withclosing`` is True, it will be opened with
-    closing, allowing use like:
-
-        with _open_shelve('somefile',True) as s:
-            ...
-    """
-    import shelve
-    import contextlib
-
-    shelf = shelve.open(shelffn, protocol=2)
-
-    if withclosing:
-        return contextlib.closing(shelf)
-    else:
-        return shelf
