@@ -3,11 +3,11 @@
 import json
 
 # The MockResponse class is currently relied upon in code and thus
-# temporarily got moved out of testing_tools to avoid adding pytest as a
+# temporarily got moved here to avoid adding pytest as a
 # mandatory dependency
 
 
-class MockResponse(object):
+class MockResponse:
     """
     A mocked/non-remote version of `astroquery.query.AstroResponse`
     """
