@@ -1,5 +1,5 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import print_function
+
 
 import os
 import warnings
@@ -7,8 +7,8 @@ import json
 import copy
 import re
 
-import six
-from six import BytesIO
+from io import BytesIO
+
 import astropy.units as u
 import astropy.coordinates as coord
 import astropy.table as tbl
@@ -33,7 +33,7 @@ __doctest_skip__ = ['VizierClass.*']
 @async_to_sync
 class VizierClass(BaseQuery):
 
-    _str_schema = schema.Or(*six.string_types)
+    _str_schema = schema.Schema(str)
     _schema_columns = schema.Schema([_str_schema],
                                     error="columns must be a list of strings")
     _schema_ucd = schema.Schema(_str_schema, error="ucd must be string")
@@ -62,6 +62,16 @@ class VizierClass(BaseQuery):
             column descriptions defined on the Vizier web pages.
             See http://vizier.u-strasbg.fr/vizier/vizHelp/1.htx#ucd and
             http://cds.u-strasbg.fr/w/doc/UCD/
+        vizier_server : string
+            Name of the VizieR mirror to use.
+            (This parameter's default is set from a configuration object.)
+        timeout : number
+            timeout for connecting to server
+            (This parameter's default is set from a configuration object.)
+        row_limit : int
+            Maximum number of rows that will be fetched from the result
+            (set to -1 for unlimited).
+            (This parameter's default is set from a configuration object.)
         """
 
         super(VizierClass, self).__init__()
@@ -250,7 +260,7 @@ class VizierClass(BaseQuery):
             Returned if asynchronous method used
         """
 
-        if not isinstance(catalog, six.string_types + (votable.tree.Resource,)):
+        if not isinstance(catalog, (str, votable.tree.Resource)):
             catalog = list(catalog)
         data_payload = self._args_to_payload(catalog=catalog)
         if get_query_payload:
@@ -316,7 +326,8 @@ class VizierClass(BaseQuery):
     def query_region_async(self, coordinates, radius=None, inner_radius=None,
                            width=None, height=None, catalog=None,
                            get_query_payload=False, cache=True,
-                           return_type='votable', column_filters={}):
+                           return_type='votable', column_filters={},
+                           frame='fk5'):
         """
         Serves the same purpose as `query_region` but only
         returns the HTTP response rather than the parsed result.
@@ -347,6 +358,10 @@ class VizierClass(BaseQuery):
         column_filters: dict, optional
             Constraints on columns of the result. The dictionary contains
             the column name as keys, and the constraints as values.
+        frame : str, optional
+            The frame to use for the request. It should be 'fk5', 'icrs',
+            or 'galactic'. This choice influences the the orientation of
+            box requests.
 
         Returns
         -------
@@ -354,31 +369,45 @@ class VizierClass(BaseQuery):
             The response of the HTTP request.
 
         """
+        if frame not in ('galactic', 'fk5', 'icrs'):
+            raise ValueError("Only the 'galactic', 'icrs', and 'fk5' frames are supported by VizieR")
         catalog = VizierClass._schema_catalog.validate(catalog)
         center = {}
         columns = []
-        if isinstance(coordinates, (commons.CoordClasses,) + six.string_types):
-            c = commons.parse_coordinates(coordinates).transform_to('fk5')
 
-            if not c.isscalar:
-                pos_list = []
-                for pos in c:
-                    ra_deg = pos.ra.to_string(unit="deg", decimal=True,
-                                              precision=8)
-                    dec_deg = pos.dec.to_string(unit="deg", decimal=True,
-                                                precision=8, alwayssign=True)
-                    pos_list += ["{}{}".format(ra_deg, dec_deg)]
-                center["-c"] = "<<;" + ";".join(pos_list)
-                columns += ["_q"]  # request a reference to the input table
+        # Process coordinates
+        if isinstance(coordinates, (commons.CoordClasses, str)):
+            target = commons.parse_coordinates(coordinates).transform_to(frame)
+
+            if not target.isscalar:
+                center["-c"] = []
+                for pos in target:
+                    if frame == 'galactic':
+                        glon_deg = pos.l.to_string(unit="deg", decimal=True, precision=8)
+                        glat_deg = pos.b.to_string(unit="deg", decimal=True, precision=8,
+                                                   alwayssign=True)
+                        center["-c"] += ["G{}{}".format(glon_deg, glat_deg)]
+                    else:
+                        ra_deg = pos.ra.to_string(unit="deg", decimal=True, precision=8)
+                        dec_deg = pos.dec.to_string(unit="deg", decimal=True,
+                                                    precision=8, alwayssign=True)
+                        center["-c"] += ["{}{}".format(ra_deg, dec_deg)]
+                columns += ["_q"]  # Always request reference to input table
             else:
-                ra = c.ra.to_string(unit='deg', decimal=True, precision=8)
-                dec = c.dec.to_string(unit="deg", decimal=True, precision=8,
-                                      alwayssign=True)
-                center["-c"] = "{ra}{dec}".format(ra=ra, dec=dec)
+                if frame == 'galactic':
+                    glon = target.l.to_string(unit='deg', decimal=True, precision=8)
+                    glat = target.b.to_string(unit="deg", decimal=True, precision=8,
+                                              alwayssign=True)
+                    center["-c"] = "G{glon}{glat}".format(glon=glon, glat=glat)
+                else:
+                    ra = target.ra.to_string(unit='deg', decimal=True, precision=8)
+                    dec = target.dec.to_string(unit="deg", decimal=True, precision=8,
+                                               alwayssign=True)
+                    center["-c"] = "{ra}{dec}".format(ra=ra, dec=dec)
         elif isinstance(coordinates, tbl.Table):
             if (("_RAJ2000" in coordinates.keys()) and ("_DEJ2000" in
                                                         coordinates.keys())):
-                pos_list = []
+                center["-c"] = []
                 sky_coord = coord.SkyCoord(coordinates["_RAJ2000"],
                                            coordinates["_DEJ2000"],
                                            unit=(coordinates["_RAJ2000"].unit,
@@ -388,15 +417,15 @@ class VizierClass(BaseQuery):
                                           precision=8)
                     dec_deg = dec.to_string(unit="deg", decimal=True,
                                             precision=8, alwayssign=True)
-                    pos_list += ["{}{}".format(ra_deg, dec_deg)]
-                center["-c"] = "<<;" + ";".join(pos_list)
-                columns += ["_q"]  # request a reference to the input table
+                    center["-c"] += ["{}{}".format(ra_deg, dec_deg)]
+                columns += ["_q"]  # Always request reference to input table
             else:
                 raise ValueError("Table must contain '_RAJ2000' and "
                                  "'_DEJ2000' columns!")
         else:
             raise TypeError("Coordinates must be one of: string, astropy "
                             "coordinates, or table containing coordinates!")
+
         # decide whether box or radius
         if radius is not None:
             # is radius a disk or an annulus?
@@ -434,6 +463,7 @@ class VizierClass(BaseQuery):
             raise Exception(
                 "At least one of radius, width/height must be specified")
 
+        # Prepare payload
         data_payload = self._args_to_payload(center=center, columns=columns,
                                              catalog=catalog, column_filters=column_filters)
 
@@ -523,7 +553,7 @@ class VizierClass(BaseQuery):
         catalog = kwargs.get('catalog') or self.catalog
 
         if catalog is not None:
-            if isinstance(catalog, six.string_types):
+            if isinstance(catalog, str):
                 body['-source'] = catalog
             elif isinstance(catalog, list):
                 catalog = [item.name if hasattr(item, 'name') else item
@@ -547,16 +577,13 @@ class VizierClass(BaseQuery):
         # keyword names that can mean 'all'
         alls = ['all', '**']
         if any(x in columns for x in alls):
+            columns_all = True
             for x in alls:
                 if x in columns:
                     columns.remove(x)
-            body['-out.all'] = 2
-        # keyword name that means default columns
-        if '*' in columns:
-            columns.remove('*')
-            columns_default = True
+            body['-out.all'] = None
         else:
-            columns_default = False
+            columns_all = False
 
         # process: columns - identify sorting requests
         columns_out = []
@@ -571,16 +598,23 @@ class VizierClass(BaseQuery):
             else:
                 columns_out += [column]
 
-        if columns_default:
-            body['-out'] = '*'
-        else:
-            body['-out'] = columns_out
+        # calculated keyword names that start with an underscore
+        columns_calc = []
+        for column in columns_out:
+            if column[0] == '_':
+                columns_calc.append(column)
+        for column in columns_calc:
+            columns_out.remove(column)
 
-        if columns_out:
-            body['-out.add'] = ','.join(columns_out)
+        if columns_out and not columns_all:
+                body['-out'] = ','.join(columns_out)
+
+        if columns_calc:
+            body['-out.add'] = ','.join(columns_calc)
 
         if len(sorts_out) > 0:
             body['-sort'] = ','.join(sorts_out)
+
         # process: maximum rows returned
         row_limit = kwargs.get('row_limit') or self.ROW_LIMIT
         if row_limit < 0:
@@ -607,14 +641,26 @@ class VizierClass(BaseQuery):
         if ucd:
             body['-ucd'] = ucd
 
-        # create final script
-        script = "\n".join(["{key}={val}".format(key=key, val=val)
-                            for key, val in body.items()])
-        # add keywords
+        # create final script starting with keywords
+        script = []
         if (not isinstance(self.keywords, property) and
                 self.keywords is not None):
-            script += "\n" + str(self.keywords)
-        return script
+            script += [str(self.keywords)]
+        # add all items that are not lists
+        for key, val in body.items():
+            if type(val) is not list:
+                if val:
+                    script += ["{key}={val}".format(key=key, val=val)]
+                else:
+                    script += [key]
+        # add list at the end
+        for key, val in body.items():
+            if type(val) is list:
+                script += ["{key}=<<====AstroqueryList".format(key=key)]
+                script += val
+                script += ["====AstroqueryList"]
+        # merge result
+        return "\n".join(script)
 
     def _parse_result(self, response, get_catalog_names=False, verbose=False,
                       invalid='warn'):
@@ -715,15 +761,15 @@ def parse_vizier_votable(data, verbose=False, invalid='warn',
     tf = BytesIO(data)
 
     if invalid == 'mask':
-        vo_tree = votable.parse(tf, pedantic=False, invalid='mask')
+        vo_tree = votable.parse(tf, verify='warn', invalid='mask')
     elif invalid == 'warn':
         try:
-            vo_tree = votable.parse(tf, pedantic=False, invalid='exception')
+            vo_tree = votable.parse(tf, verify='warn', invalid='exception')
         except Exception as ex:
             warnings.warn("VOTABLE parsing raised exception: {0}".format(ex))
-            vo_tree = votable.parse(tf, pedantic=False, invalid='mask')
+            vo_tree = votable.parse(tf, verify='warn', invalid='mask')
     elif invalid == 'exception':
-        vo_tree = votable.parse(tf, pedantic=False, invalid='exception')
+        vo_tree = votable.parse(tf, verify='warn', invalid='exception')
     else:
         raise ValueError("Invalid keyword for 'invalid'. "
                          "Must be exception, mask, or warn")
@@ -797,7 +843,7 @@ class VizierKeyword(list):
 
     @keywords.setter
     def keywords(self, values):
-        if isinstance(values, six.string_types):
+        if isinstance(values, str):
             values = list(values)
         keys = [key.lower() for key in self.keyword_dict]
         values = [val.lower() for val in values]
