@@ -1,6 +1,7 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 
-import six
+from io import StringIO
+
 from astropy.io import ascii
 import astropy.units as u
 from astropy.table import Table
@@ -109,18 +110,18 @@ class XMatchClass(BaseQuery):
 
         return response
 
-    def _prepare_sending_table(self, i, payload, kwargs, cat, colRA, colDec):
+    def _prepare_sending_table(self, cat_index, payload, kwargs, cat, colRA, colDec):
         '''Check if table is a string, a `astropy.table.Table`, etc. and set
         query parameters accordingly.
         '''
-        catstr = 'cat{0}'.format(i)
-        if isinstance(cat, six.string_types):
+        catstr = 'cat{0}'.format(cat_index)
+        if isinstance(cat, str):
             payload[catstr] = cat
         elif isinstance(cat, Table):
             # write the Table's content into a new, temporary CSV-file
             # so that it can be pointed to via the `files` option
             # file will be closed when garbage-collected
-            fp = six.StringIO()
+            fp = StringIO()
             cat.write(fp, format='ascii.csv')
             fp.seek(0)
             kwargs['files'] = {catstr: ('cat1.csv', fp.read())}
@@ -134,8 +135,8 @@ class XMatchClass(BaseQuery):
                                  ' the input table.')
             # if `cat1` is not a VizieR table,
             # it is assumed it's either a URL or an uploaded table
-            payload['colRA{0}'.format(i)] = colRA
-            payload['colDec{0}'.format(i)] = colDec
+            payload['colRA{0}'.format(cat_index)] = colRA
+            payload['colDec{0}'.format(cat_index)] = colDec
 
     def _prepare_area(self, payload, area):
         '''Set the area parameter in the payload'''
@@ -158,7 +159,7 @@ class XMatchClass(BaseQuery):
 
         # table_id can actually be a Table instance, there is no point in
         # comparing those to stings
-        if not isinstance(table_id, six.string_types):
+        if not isinstance(table_id, str):
             return False
 
         if (table_id[:7] == 'vizier:'):
@@ -187,12 +188,12 @@ class XMatchClass(BaseQuery):
         """
         header = text.split("\n")[0]
         colnames = header.split(",")
-        for cn in colnames:
-            if colnames.count(cn) > 1:
-                ii = 1
-                while colnames.count(cn) > 0:
-                    colnames[colnames.index(cn)] = cn + "_{ii}".format(ii=ii)
-                    ii += 1
+        for column in colnames:
+            if colnames.count(column) > 1:
+                counter = 1
+                while colnames.count(column) > 0:
+                    colnames[colnames.index(column)] = column + "_{counter}".format(counter=counter)
+                    counter += 1
         new_text = ",".join(colnames) + "\n" + "\n".join(text.split("\n")[1:])
         result = ascii.read(new_text, format='csv', fast_reader=False)
 
